@@ -1,10 +1,10 @@
 /*
- Emacs: -*- mode: c++; c-basic-offset: 4; -*-
 
  ark -- archiver for the KDE project
 
  Copyright (C)
 
+ 2004-2005: Henrique Pinto <henrique.pinto@kdemail.net>
  2003: Georg Robbers <Georg.Robbers@urz.uni-hd.de>
  2002-2003: Helio Chissini de Castro <helio@conectiva.com.br>
  2001-2002: Roberto Teixeira <maragato@kde.org>
@@ -37,6 +37,7 @@
 #include <qstringlist.h>
 #include <qlabel.h>
 #include <qcheckbox.h>
+#include <qdir.h>
 
 // KDE includes
 #include <kdebug.h>
@@ -58,13 +59,13 @@
 #include <ktoolbar.h>
 #include <kconfigdialog.h>
 #include <ktrader.h>
+#include <kurl.h>
 
 // settings
 #include "settings.h"
 #include "general.h"
 #include "addition.h"
 #include "extraction.h"
-#include "folders.h"
 #include <kpopupmenu.h>
 #include <kdialog.h>
 
@@ -106,9 +107,9 @@ static void viewInExternalViewer( ArkWidget* parent, const QString& filename )
 
 ArkWidget::ArkWidget( QWidget *parent, const char *name ) :
         QVBox(parent, name), m_bBusy( false ), m_bBusyHold( false ),
-	m_extractOnly( false ), m_extractRemote(false), 
-	m_openAsMimeType(QString::null), m_pTempAddList(NULL), 
-	mpDownloadedList(NULL), m_bArchivePopupEnabled( false ), 
+	m_extractOnly( false ), m_extractRemote(false),
+	m_openAsMimeType(QString::null), m_pTempAddList(NULL),
+	m_bArchivePopupEnabled( false ),
 	m_convert_tmpDir( NULL ), m_convertSuccess( false ),
 	m_createRealArchTmpDir( NULL ),	m_extractRemoteTmpDir( NULL ),
 	m_modified( false ), m_searchToolBar( 0 ), m_searchBar( 0 ),
@@ -126,7 +127,7 @@ ArkWidget::ArkWidget( QWidget *parent, const char *name ) :
 	                      << m_tmpDir->status() << "." << endl;
 	    m_tmpDir = NULL;
     }
-	
+
     m_searchToolBar = new KToolBar( this, "searchBar" );
     m_searchToolBar->boxLayout()->setSpacing( KDialog::spacingHint() );
 
@@ -138,7 +139,7 @@ ArkWidget::ArkWidget( QWidget *parent, const char *name ) :
 
     if ( !Settings::showSearchBar() )
         m_searchToolBar->hide();
-    
+
     createFileListView();
 
     m_searchBar->setListView( archiveContent );
@@ -151,7 +152,6 @@ ArkWidget::~ArkWidget()
 {
     cleanArkTmpDir();
     ready();
-    delete mpDownloadedList;
     delete m_pTempAddList;
     delete archiveContent;
     archiveContent = 0;
@@ -161,28 +161,13 @@ ArkWidget::~ArkWidget()
 
 void ArkWidget::cleanArkTmpDir()
 {
+        removeDownloadedFiles();
 	if ( m_tmpDir )
 	{
 		m_tmpDir->unlink();
 		delete m_tmpDir;
 		m_tmpDir = NULL;
 	}
-	return;
-}
-
-const FileLVI * ArkWidget::getFileLVI( const QString& _filename ) const
-{
-	FileLVI * flvi = ( FileLVI* ) archiveContent->firstChild();
-	
-	while ( flvi )
-	{
-		QString curFilename = flvi->fileName();
-		if ( curFilename == _filename )
-			return flvi;
-		flvi = ( FileLVI* ) flvi->itemBelow();
-	}
-	
-	return 0;
 }
 
 void ArkWidget::setHeaders( QStringList* _headers, int * _rightAlignCols, int _numColsToAlignRight )
@@ -209,19 +194,6 @@ void ArkWidget::clearHeaders()
 	}
 }
 
-void ArkWidget::listingAdd( QStringList * _entries )
-{
-	FileLVI *flvi = new FileLVI( archiveContent );
-
-	int i = 0;
-	
-	for ( QStringList::Iterator it = _entries->begin(); it != _entries->end(); ++it )
-	{
-		flvi->setText( i, *it );
-		++i;
-	}
-}
-
 void ArkWidget::viewShellOutput()
 {
 	ShellOutputDlg* sod = new ShellOutputDlg( arch->getLastShellOutput(), this );
@@ -420,7 +392,7 @@ ArkWidget::convertSlotCreateDone( bool success )
     }
     bool bOldRecVal = Settings::rarRecurseSubdirs();
     connect( arch, SIGNAL( sigAdd( bool ) ), this, SLOT( convertSlotAddDone( bool ) ) );
-    arch->addFile( &entries );
+    arch->addFile( entries );
     Settings::setRarRecurseSubdirs( bOldRecVal );
 }
 
@@ -689,29 +661,42 @@ ArkWidget::addToArchiveSlotOpenDone( bool success )
         }
     }
 
-    QStringList list = m_addToArchive_filesToAdd.toStringList();
+/*    QStringList list = m_addToArchive_filesToAdd.toStringList();
     if ( !ArkUtils::diskHasSpace( tmpDir(), ArkUtils::getSizes( &list ) ) )
     {
         KMessageBox::error( this, i18n( "Not enough free disc space to extract the archive." ) );
         emit request_file_quit();
         return;
-    }
+    }*/
 
     disableAll();
     // if they are URLs, we have to download them, replace the URLs
     // with filenames, and remember to delete the temporaries later.
-    for ( QStringList::Iterator it = list.begin();
+/*    for ( QStringList::Iterator it = list.begin();
          it != list.end(); ++it)
     {
         QString str = *it;
         KURL url( toLocalFile( str ) );
         *it = url.prettyURL();
     }
+*/
+    KURL::List list = m_addToArchive_filesToAdd;
+
+
+    // Remote URLs need to be downloaded.
+    KURL::List::Iterator end( list.end() );
+    for ( KURL::List::Iterator it = list.begin(); it != end; ++it )
+    {
+        if (!(*it).isLocalFile())
+        {
+            *it = toLocalFile( *it );
+        }
+    }
 
     kdDebug( 1601 ) << "Adding: " << list << endl;
 
     connect( arch, SIGNAL( sigAdd( bool ) ), this, SLOT( addToArchiveSlotAddDone( bool ) ) );
-    arch->addFile( &list );
+    arch->addFile( list.toStringList() );
 }
 
 void
@@ -737,7 +722,6 @@ void ArkWidget::setOpenAsMimeType( const QString & mimeType )
 void
 ArkWidget::file_open(const KURL& url)
 {
-    kdDebug(1601) << "+ArkWidget::file_open(const KURL& url)" << endl;
     if ( url.isEmpty() )
     {
         kdDebug( 1601 ) << "file_open: url empty" << endl;
@@ -789,8 +773,6 @@ ArkWidget::file_open(const KURL& url)
     //arch->clearShellOutput();
 
     openArchive( strFile );
-
-    kdDebug(1601) << "-ArkWidget::file_open(const KURL& url)" << endl;
 }
 
 
@@ -810,10 +792,8 @@ ArkWidget::getCreateFilename(const QString & _caption,
     KFileDialog dlg( ":ArkSaveAsDialog", QString::null, this, "SaveAsDialog", true );
     dlg.setCaption( _caption );
     dlg.setOperationMode( KFileDialog::Saving );
-    dlg.setFilterMimeType( i18n( "Archive &format:" ),
-           ArchiveFormatInfo::self()->supportedMimeTypes( allowCompressed ),
-           _defaultMimeType.isNull() ? KMimeType::mimeType( "application/x-tgz" )
-                                     : KMimeType::mimeType( _defaultMimeType ) );
+    dlg.setMimeFilter( ArchiveFormatInfo::self()->supportedMimeTypes( allowCompressed ),
+                       _defaultMimeType.isNull() ?  "application/x-tgz" : _defaultMimeType );
     if ( !_suggestedName.isEmpty() )
         dlg.setSelection( _suggestedName );
 
@@ -898,17 +878,8 @@ ArkWidget::file_new()
 void
 ArkWidget::extractOnlyOpenDone()
 {
-    int oldMode = Settings::extractDirMode();
-    QString oldFixedExtractDir = Settings::extractDir();
-
-    Settings::setLastExtractDir( m_url.upURL().path() );
-    Settings::setExtractDirMode( 2 ); // 2 means use custom dir
-    
     bool done = action_extract();
-    // Extract should have started before this returns, so hopefully safe.
-    Settings::setLastExtractDir( oldFixedExtractDir );
-    Settings::setExtractDirMode( oldMode );
-    
+
     // last extract dir is still set, but this is not a problem
     if( !done )
     {
@@ -1011,7 +982,6 @@ ArkWidget::fixEnables() // private
 void
 ArkWidget::file_close()
 {
-    kdDebug(1601) << "+ArkWidget::file_close" << endl;
     if ( isArchiveOpen() )
     {
         closeArch();
@@ -1028,8 +998,6 @@ ArkWidget::file_close()
 
     m_strArchName = QString::null;
     m_url = KURL();
-
-    kdDebug(1601) << "-ArkWidget::file_close" << endl;
 }
 
 
@@ -1183,7 +1151,7 @@ ArkWidget::createRealArchiveSlotCreate( Arch * newArch, bool success,
     connect( newArch, SIGNAL( sigAdd( bool ) ), this,
                       SLOT( createRealArchiveSlotAddDone( bool ) ) );
 
-    newArch->addFile(&listForCompressedFile);
+    newArch->addFile(listForCompressedFile);
 }
 
 void
@@ -1249,7 +1217,7 @@ ArkWidget::action_add()
         return;
     }
 
-    KFileDialog fileDlg( Settings::addDir(), QString::null, this, "adddlg", true );
+    KFileDialog fileDlg( ":ArkAddDir", QString::null, this, "adddlg", true );
     fileDlg.setMode( KFile::Mode( KFile::Files | KFile::ExistingOnly ) );
     fileDlg.setCaption(i18n("Select Files to Add"));
 
@@ -1258,7 +1226,9 @@ ArkWidget::action_add()
         KURL::List addList;
         addList = fileDlg.selectedURLs();
         QStringList * list = new QStringList();
-        for (KURL::List::ConstIterator it = addList.begin(); it != addList.end(); it++)
+        //Here we pre-calculate the end of the list
+	KURL::List::ConstIterator endList = addList.end();
+        for (KURL::List::ConstIterator it = addList.begin(); it != endList; ++it)
             list->append( KURL::decode_string( (*it).url() ) );
 
         if ( list->count() > 0 )
@@ -1294,29 +1264,27 @@ ArkWidget::addFile(QStringList *list)
     for (QStringList::Iterator it = list->begin(); it != list->end(); ++it)
     {
         QString str = *it;
-        //kdDebug(1601) << "Want to add " << str<< endl;
-        KURL url( toLocalFile(str) );
-        *it = url.prettyURL();
+        *it = toLocalFile(KURL(str)).prettyURL();
 
     }
 
     connect( arch, SIGNAL( sigAdd( bool ) ), this, SLOT( slotAddDone( bool ) ) );
-    arch->addFile(list);
+    arch->addFile( ( *list ) );
 }
 
 void
 ArkWidget::action_add_dir()
 {
-    KURL u = KDirSelectDialog::selectDirectory( Settings::addDir(),
-                                                    false, this,
-                                                    i18n("Select Folder to Add"));
+    KURL u = KDirSelectDialog::selectDirectory( ":ArkAddDir",
+                                                false, this,
+                                                i18n("Select Folder to Add"));
 
     QString dir = KURL::decode_string( u.url(-1) );
     if ( !dir.isEmpty() )
     {
         busy( i18n( "Adding folder..." ) );
         disableAll();
-        u = toLocalFile(dir);
+        u = toLocalFile(u);
         connect( arch, SIGNAL( sigAdd( bool ) ), this, SLOT( slotAddDone( bool ) ) );
         arch->addDir( u.prettyURL() );
     }
@@ -1327,7 +1295,6 @@ void
 ArkWidget::slotAddDone(bool _bSuccess)
 {
     disconnect( arch, SIGNAL( sigAdd( bool ) ), this, SLOT( slotAddDone( bool ) ) );
-    kdDebug(1601) << "+ArkWidget::slotAddDone" << endl;
     archiveContent->setUpdatesEnabled(true);
     archiveContent->triggerUpdate();
     ready();
@@ -1342,37 +1309,52 @@ ArkWidget::slotAddDone(bool _bSuccess)
         file_open( u );
         emit setWindowCaption( u.path() );
     }
-    if (mpDownloadedList)
-    {
-        // is this necessary? Maybe risky. The tmp/ark.### directory
-        // will be removed anyhow...
-        KIO::del( *mpDownloadedList, false, false );
-        delete mpDownloadedList;
-        mpDownloadedList = NULL;
-    }
+    removeDownloadedFiles();
     fixEnables();
-    kdDebug(1601) << "-ArkWidget::slotAddDone" << endl;
 }
 
 
 
 KURL
-ArkWidget::toLocalFile( QString & str )
+ArkWidget::toLocalFile( const KURL& url )
 {
-    KURL url = str;
+    KURL localURL = url;
 
     if(!url.isLocalFile())
     {
-        if(!mpDownloadedList)
-            mpDownloadedList = new QStringList();
+	QString strURL = url.prettyURL();
+
         QString tempfile = tmpDir();
-        tempfile += str.right(str.length() - str.findRev("/") - 1);
-        if( !KIO::NetAccess::dircopy(url, tempfile, this) )
+        tempfile += strURL.right(strURL.length() - strURL.findRev("/") - 1);
+        deleteAfterUse(tempfile);  // remember for deletion
+        KURL tempurl; tempurl.setPath( tempfile );
+        if( !KIO::NetAccess::dircopy(url, tempurl, this) )
             return KURL();
-        mpDownloadedList->append(tempfile);        // remember for deletion
-        url = tempfile;
+        localURL = tempfile;
+    }
+    return localURL;
+}
+
+void
+ArkWidget::deleteAfterUse( const QString& path )
+{
+    mpDownloadedList.append( path );
+}
+
+void
+ArkWidget::removeDownloadedFiles()
+{
+    if (!mpDownloadedList.isEmpty())
+    {
+        // It is necessary to remove those files even if tmpDir() is getting deleted:
+        // not all files in mpDownloadedList are from tmpDir() - e.g. when using --tempfile
+        // But of course we could decide to not add files from tmpDir() into mpDownloadedList.
+        QStringList::ConstIterator it = mpDownloadedList.begin();
+        QStringList::ConstIterator end = mpDownloadedList.end();
+        for ( ; it != end ; ++it )
+            QFile::remove( *it );
+        mpDownloadedList.clear();
     }
-    return url;
 }
 
 void
@@ -1541,6 +1523,11 @@ ArkWidget::prepareViewFiles( const QStringList & fileList )
     QString destTmpDirectory;
     destTmpDirectory = tmpDir();
 
+    // Make sure to delete previous file already there...
+    for(QStringList::ConstIterator it = fileList.begin();
+        it != fileList.end(); ++it)
+        QFile::remove(destTmpDirectory + *it);
+
     QStringList * list = new QStringList( fileList );
     arch->unarchFile( list, destTmpDirectory, true);
     delete list;
@@ -1633,13 +1620,13 @@ ArkWidget::action_extract()
     kdDebug(1601) << "+action_extract" << endl;
 
 
-	 KURL fileToExtract;
+    KURL fileToExtract;
 
     fileToExtract.setPath( arch->fileName() );
 
-	 kdDebug(1601) << "Archive to extract: " << fileToExtract.prettyURL() << endl;
+    kdDebug(1601) << "Archive to extract: " << fileToExtract.prettyURL() << endl;
 
-	 //before we start, make sure the archive is still there
+     //before we start, make sure the archive is still there
     if (!KIO::NetAccess::exists( fileToExtract.prettyURL(), true, this ) )
     {
         KMessageBox::error(0, i18n("The archive to extract from no longer exists."));
@@ -1669,7 +1656,20 @@ ArkWidget::action_extract()
     }
 
 
-    ExtractDlg *dlg = new ExtractDlg(this, 0, m_url.filename(), prefix);
+    ExtractDlg *dlg = new ExtractDlg(this, 0, m_url.fileName());
+    
+    QString tmp; // for KFileDialog::getStartUrl()
+    
+    if (m_extractOnly)
+    {
+      dlg->setURL( KURL::fromPathOrURL( QDir::currentDirPath() ) );
+    }
+    if (!prefix.isNull())
+    {
+      QString tmp;
+      KURL baseURL = KFileDialog::getStartURL( ":ArkExtractDir", tmp );
+      dlg->setURL( baseURL.url() + prefix );
+    }
 
     // if they choose pattern, we have to tell arkwidget to select
     // those files... once we're in the dialog code it's too late.
@@ -1911,7 +1911,7 @@ ArkWidget::slotEditFinished(KProcess *kp)
     }
 
     busy( i18n( "Readding edited file..." ) );
-    arch->addFile( &list );
+    arch->addFile( list );
 
     kdDebug(1601) << "-ArkWidget::slotEditFinished" << endl;
 }
@@ -2449,7 +2449,6 @@ void
 ArkWidget::slotOpen( Arch * /* _newarch */, bool _success, const QString & _filename, int )
 {
     ready();
-    kdDebug(1601) << "+ArkWidget::slotOpen" << endl;
     archiveContent->setUpdatesEnabled(true);
     archiveContent->triggerUpdate();
 
@@ -2459,7 +2458,6 @@ ArkWidget::slotOpen( Arch * /* _newarch */, bool _success, const QString & _file
     {
         QFileInfo fi( _filename );
         QString path = fi.dirPath( true );
-	Settings::setLastOpenDir( path );
 
         if ( !fi.isWritable() )
         {
@@ -2489,7 +2487,6 @@ ArkWidget::slotOpen( Arch * /* _newarch */, bool _success, const QString & _file
 
     fixEnables();
     emit openDone( _success );
-    kdDebug(1601) << "-ArkWidget::slotOpen" << endl;
 }
 
 
@@ -2513,14 +2510,13 @@ void ArkWidget::slotShowSearchBarToggled( bool b )
 void ArkWidget::showSettings(){
   if(KConfigDialog::showDialog("settings"))
     return;
-  
+
   KConfigDialog *dialog = new KConfigDialog(this, "settings", Settings::self());
 
   General* genPage = new General(0, "General");
   dialog->addPage(genPage, i18n("General"), "ark", i18n("General Settings"));
   dialog->addPage(new Addition(0, "Addition"), i18n("Addition"), "ark_addfile", i18n("File Addition Settings"));
   dialog->addPage(new Extraction(0, "Extraction"), i18n("Extraction"), "ark_extract", i18n("Extraction Settings"));
-  dialog->addPage(new Folders(0, "Folders"), i18n("Folders"), "folder", i18n("Folder Settings"));
 
   KTrader::OfferList offers;
 
@@ -2530,7 +2526,7 @@ void ArkWidget::showSettings(){
 	  genPage->kcfg_KonquerorIntegration->setEnabled( false );
   else
 	  genPage->konqIntegrationLabel->setText( QString::null );
-  
+
   dialog->show();
 }
 
