@@ -1,7 +1,7 @@
 //  -*-C++-*-           emacs magic for .h files
 /*
 
- $Id: extractdlg.h,v 1.30 2004/06/22 02:57:59 pinto Exp $
+ $Id: extractdlg.h,v 1.32 2005/01/20 11:38:27 pinto Exp $
 
  ark -- archiver for the KDE project
 
@@ -36,8 +36,6 @@
 #include <qcheckbox.h>
 #include <kurl.h>
 
-#include "arch.h"
-
 class QWidget;
 class QString;
 class QStringList;
@@ -54,7 +52,7 @@ class ExtractDlg : public KDialogBase
 {
   Q_OBJECT
 public:
-  ExtractDlg(QWidget *parent=0, const char *name=0, const QString &archiveName=QString::null, const QString &prefix=QString::null);
+  ExtractDlg(QWidget *parent=0, const char *name=0, const QString &archiveName=QString::null);
   ~ExtractDlg();
   enum ExtractOp{ All, Selected, Current, Pattern };
   int extractOp();
@@ -62,6 +60,8 @@ public:
   void disableSelectedFilesOption();
   void disableCurrentFileOption() { m_radioCurrent->setEnabled(false); }
   bool viewFolderAfterExtraction() const { return m_viewFolderAfterExtraction->isChecked(); }
+  
+  void setURL( const KURL& );
 public slots:
   //void browse();
   void choosePattern() { m_radioPattern->setChecked(true); }
