@@ -52,6 +52,7 @@
 #include <qregexp.h>
 
 // KDE includes
+#include <kapplication.h>
 #include <kdebug.h>
 #include <klargefile.h>
 #include <klocale.h>
@@ -388,12 +389,15 @@ void TarArch::processDir(const KTarDirectory *tardir, const QString & root)
       const KTarEntry* tarEntry = tardir->entry((*it));
       if (tarEntry == NULL)
         return;
+
       QStringList col_list;
       QString name;
       if (root.isEmpty() || root.isNull())
         name = tarEntry->name();
       else
-        name = root + '/' + tarEntry->name();
+        name = root + tarEntry->name();
+      if ( !tarEntry->isFile() )
+        name += '/';
       col_list.append( name );
       QString perms = makeAccessString(tarEntry->permissions());
       if (!tarEntry->isFile())
@@ -414,12 +418,13 @@ void TarArch::processDir(const KTarDirectory *tardir, const QString & root)
       QString timestamp = tarEntry->datetime().toString(ISODate);
       col_list.append(timestamp);
       col_list.append(tarEntry->symlink());
-      m_gui->listingAdd(&col_list); // send the entry to the GUI
+      m_gui->fileList()->addItem(col_list); // send the entry to the GUI
 
       // if it isn't a file, it's a directory - process it.
       // remember that name is root + / + the name of the directory
       if (!tarEntry->isFile())
         processDir( (KTarDirectory *)tarEntry, name);
+      kapp->processEvents(20);
     }
   // kdDebug(1601) << "-TarArch::processDir" << endl;
 }
@@ -545,18 +550,18 @@ void TarArch::createTmpProgress( KProcess * _proc, char *_buffer, int _bufflen )
     }
 }
 
-void TarArch::deleteOldFiles(QStringList *urls, bool bAddOnlyNew)
+void TarArch::deleteOldFiles(const QStringList &urls, bool bAddOnlyNew)
   // because tar is broken. Used when appending: see addFile.
 {
   QStringList list;
   QString str;
 
   QStringList::ConstIterator iter;
-  for (iter = urls->begin(); iter != urls->end(); ++iter )
+  for (iter = urls.begin(); iter != urls.end(); ++iter )
   {
     KURL url( *iter );
     // find the file entry in the archive listing
-    const FileLVI * lv = m_gui->getFileLVI( url.fileName() );
+    const FileLVI * lv = m_gui->fileList()->item( url.fileName() );
     if ( !lv ) // it isn't in there, so skip it.
       continue;
 
@@ -598,10 +603,10 @@ void TarArch::deleteOldFiles(QStringList *urls, bool bAddOnlyNew)
 }
 
 
-void TarArch::addFile( QStringList* urls )
+void TarArch::addFile( const QStringList&  urls )
 {
-  kdDebug(1601) << "+TarArch::addFile" << ( urls->first() ) << endl;
-  m_filesToAdd = *urls;
+  kdDebug(1601) << "+TarArch::addFile" << ( urls.first() ) << endl;
+  m_filesToAdd = urls;
   // tar is broken. If you add a file that's already there, it gives you
   // two entries for that name, whether you --append or --update. If you
   // extract by name, it will give you
@@ -837,7 +842,7 @@ void TarArch::addDir(const QString & _dirName)
 {
   QStringList list;
   list.append(_dirName);
-  addFile(&list);
+  addFile(list);
 }
 
 void TarArch::openFinished( KProcess * )
