@@ -1,5 +1,5 @@
 /*
-    $Id: dlabel.cpp,v 1.12 2003/10/14 21:42:32 kniederk Exp $
+    $Id: dlabel.cpp,v 1.16 2004/12/03 00:55:31 kniederk Exp $
 
     KCalc, a scientific calculator for the X window system using the
     Qt widget libraries, available at no cost at http://www.troll.no
@@ -23,14 +23,26 @@
 
 */
 
+#include <qglobal.h>
+#include <kactioncollection.h>
+#include <kstdaction.h>
+
 #include "kcalc_settings.h"
 #include "kcalc_core.h"
 #include "dlabel.h"
 #include "dlabel.moc"
 
-DispLogic::DispLogic(QWidget *parent, const char *name)
+
+
+DispLogic::DispLogic(QWidget *parent, const char *name,
+		     KActionCollection *coll)
   :KCalcDisplay(parent,name), _history_index(0)
 {
+	_back = KStdAction::undo(this, SLOT(history_back()), coll);
+	_forward = KStdAction::redo(this, SLOT(history_forward()), coll);
+
+	_forward->setEnabled(false);
+	_back->setEnabled(false);
 }
 
 DispLogic::~DispLogic()
@@ -58,19 +70,24 @@ void DispLogic::changeSettings()
 		setFixedPrecision(KCalcSettings::fixedPrecision());
 
 	setBeep(KCalcSettings::beep());
+	setGroupDigits(KCalcSettings::groupDigits());
+	updateDisplay();
 }
 
 void DispLogic::update_from_core(CalcEngine const &core,
 				 bool store_result_in_history)
 {
 	bool tmp_error;
-	CALCAMNT output = core.last_output(tmp_error);
-	setError(tmp_error);
+	CALCAMNT output = core.lastOutput(tmp_error);
+	if(tmp_error) sendEvent(EventError);
 	if (setAmount(output)  &&  store_result_in_history  &&
 	    output != 0)
 	{
 	  // add this latest value to our history
 	  _history_list.insert(_history_list.begin(), output);
+	  _history_index = 0;
+	  _back->setEnabled(true);
+	  _forward->setEnabled(false);
 	}
 }
 
@@ -135,19 +152,30 @@ void DispLogic::EnterDigit(int data)
 	newCharacter(tmp);
 }
 
-bool DispLogic::history_next()
+void DispLogic::history_forward()
 {
-  	if((_history_list.empty()) || (_history_index <= 0))
-		return false;
+	Q_ASSERT(! _history_list.empty());
+	Q_ASSERT(_history_index > 0);
 
-	return setAmount(_history_list[--_history_index]);
+	_history_index --;
+
+	setAmount(_history_list[_history_index]);
+
+	if(_history_index == 0) _forward->setEnabled(false);
+
+	_back->setEnabled(true);
 }
 
-bool DispLogic::history_prev()
+void DispLogic::history_back()
 {
-	if((_history_list.empty()) || (_history_index >= ((int)_history_list.size() - 1)))
-		return false;
+	Q_ASSERT(! _history_list.empty());
+	Q_ASSERT(_history_index < int(_history_list.size()));
 
-	return setAmount(_history_list[++_history_index]);
+	setAmount(_history_list[_history_index]);
+
+	_history_index ++;
+	
+	if(_history_index == int(_history_list.size())) _back->setEnabled(false);
+	_forward->setEnabled(true);
 }
 
