@@ -27,48 +27,51 @@
 #include <stdlib.h>
 #include <unistd.h>
 
+
+#include <qbuttongroup.h>
+#include <qfont.h>
+#include <qhbuttongroup.h>
 #include <qlayout.h>
 #include <qobjectlist.h>
-#include <qbuttongroup.h>
-#include <qhbuttongroup.h>
 #include <qradiobutton.h>
-#include <qtooltip.h>
+#include <qspinbox.h>
 #include <qstyle.h>
-#include <qfont.h>
+#include <qtooltip.h>
+
+
 
 #include <kaboutdata.h>
 #include <kaccel.h>
 #include <kaction.h>
 #include <kapplication.h>
-#include <kconfigdialog.h>
 #include <kcmdlineargs.h>
+#include <kcolorbutton.h>
 #include <kcolordrag.h>
 #include <kconfig.h>
+#include <kconfigdialog.h>
+#include <kdialog.h>
+#include <kfontdialog.h>
 #include <kglobal.h>
 #include <kglobalsettings.h>
+#include <kkeydialog.h>
+#include <kmenubar.h>
 #include <knotifyclient.h>
-#include <kpushbutton.h>
+#include <knumvalidator.h>
 #include <kpopupmenu.h>
+#include <kpushbutton.h>
 #include <kstatusbar.h>
 #include <kstdaction.h>
-#include <kfontdialog.h>
-#include <qlayout.h>
-#include <kdialog.h>
-#include <kcolorbutton.h>
-#include <qspinbox.h>
-#include <kkeydialog.h>
-#include <knumvalidator.h>
 
 #include "dlabel.h"
 #include "kcalc.h"
+#include "kcalc_const_menu.h"
 #include "version.h"
 #include "general.h"
 #include "colors.h"
 #include "constants.h"
-
+#include <kaccelmanager.h>
 #include "kcalc_settings.h"
 
-const CALCAMNT KCalculator::pi = (ASIN(1L) * 2L);
 
 
 static const char description[] = I18N_NOOP("KDE Calculator");
@@ -77,19 +80,18 @@ static const char version[] = KCALCVERSION;
 
 KCalculator::KCalculator(QWidget *parent, const char *name)
 	: KMainWindow(parent, name), inverse(false),
-	  hyp_mode(false), memory_num(0.0),calc_display(NULL),
-	  mInternalSpacing(4),
-	  core()
+	  hyp_mode(false), memory_num(0.0), calc_display(NULL),
+	  mInternalSpacing(4), core()
 {
 	/* central widget to contain all the elements */
 	QWidget *central = new QWidget(this);
 	setCentralWidget(central);
+	KAcceleratorManager::setNoAccel( central );
 
 	// Detect color change
 	connect(kapp,SIGNAL(kdisplayPaletteChanged()), SLOT(set_colors()));
 
-	calc_display = new DispLogic(central, "display");
-
+	calc_display = new DispLogic(central, "display", actionCollection());
 
 	setupMainActions();
 
@@ -127,16 +129,17 @@ KCalculator::KCalculator(QWidget *parent, const char *name)
 	// Create Button to select AngleMode
 	pbAngleChoose =  new QPushButton(i18n("&Angle"),
 					 central, "ChooseAngleMode-Button");
-	QToolTip::add(pbAngleChoose, i18n("???"));
+	QToolTip::add(pbAngleChoose, i18n("Choose the unit for the angle measure"));
 	pbAngleChoose->setAutoDefault(false);
 
-	KPopupMenu *base_menu = new KPopupMenu(pbAngleChoose, "AngleMode-Selection-Menu");
-	connect(base_menu, SIGNAL(activated(int)), SLOT(slotAngleSelected(int)));
-	base_menu->insertItem(i18n("Degrees"), 0);
-	base_menu->insertItem(i18n("Radians"), 1);
-	base_menu->insertItem(i18n("Gradians"), 2);
+	KPopupMenu *angle_menu = new KPopupMenu(pbAngleChoose, "AngleMode-Selection-Menu");
+	angle_menu->insertItem(i18n("Degrees"), 0);
+	angle_menu->insertItem(i18n("Radians"), 1);
+	angle_menu->insertItem(i18n("Gradians"), 2);
 
-	pbAngleChoose->setPopup(base_menu);
+	angle_menu->setCheckable(true);
+	connect(angle_menu, SIGNAL(activated(int)), SLOT(slotAngleSelected(int)));
+	pbAngleChoose->setPopup(angle_menu);
 
 
 
@@ -163,15 +166,10 @@ KCalculator::KCalculator(QWidget *parent, const char *name)
 	setupTrigKeys(mSmallPage);
 	setupConstantsKeys(mSmallPage);
 
-	pbPi = new KCalcButton(mSmallPage, "Pi-Button");
-	pbPi->addMode(ModeNormal, QString::fromUtf8("π", -1), // Pi in utf8
-		      i18n("Pi=3.1415..."));
-	connect(this, SIGNAL(switchShowAccels(bool)),
-		pbPi, SLOT(slotSetAccelDisplayMode(bool)));
-	connect(pbPi, SIGNAL(clicked(void)), SLOT(slotPiclicked(void)));
 
 	pbMod = new KCalcButton(mSmallPage, "Modulo-Button");
 	pbMod->addMode(ModeNormal, "Mod", i18n("Modulo"));
+	pbMod->addMode(ModeInverse, "IntDiv", i18n("Integer division"));
 	pbMod->setAccel(Key_Colon);
 	connect(this, SIGNAL(switchMode(ButtonModeFlags,bool)),
 		pbMod, SLOT(slotSetMode(ButtonModeFlags,bool)));
@@ -197,15 +195,25 @@ KCalculator::KCalculator(QWidget *parent, const char *name)
 	// changeRepresentation() that paints the letters When
 	// pressing the INV Button a sqrt symbol will be drawn on that
 	// button
-	pbSquare = new KSquareButton(mSmallPage, "Square-Button");
+	pbSquare = new KCalcButton(mSmallPage, "Square-Button");
 	pbSquare->addMode(ModeNormal, "x<sup>2</sup>", i18n("Square"), true);
-	pbSquare->addMode(ModeInverse, "sqrt(x)", i18n("Square root"));
+	pbSquare->addMode(ModeInverse, "x<sup>3</sup>", i18n("Third power"), true);
 	connect(this, SIGNAL(switchShowAccels(bool)),
 		pbSquare, SLOT(slotSetAccelDisplayMode(bool)));
         connect(this, SIGNAL(switchMode(ButtonModeFlags,bool)),
                 pbSquare, SLOT(slotSetMode(ButtonModeFlags,bool)));
 	connect(pbSquare, SIGNAL(clicked(void)), SLOT(slotSquareclicked(void)));
 
+	pbRoot = new KSquareButton(mSmallPage, "Square-Button");
+	pbRoot->addMode(ModeNormal, "sqrt(x)", i18n("Square root"));
+	pbRoot->addMode(ModeInverse, "sqrt[3](x)", i18n("Cube root"));
+	connect(this, SIGNAL(switchShowAccels(bool)),
+		pbRoot, SLOT(slotSetAccelDisplayMode(bool)));
+        connect(this, SIGNAL(switchMode(ButtonModeFlags,bool)),
+                pbRoot, SLOT(slotSetMode(ButtonModeFlags,bool)));
+	connect(pbRoot, SIGNAL(clicked(void)), SLOT(slotRootclicked(void)));
+
+
 	// Representation of x^y is moved to the function
 	// changeRepresentation() that paints the letters When
 	// pressing the INV Button y^x will be drawn on that button
@@ -250,44 +258,44 @@ KCalculator::KCalculator(QWidget *parent, const char *name)
 	smallBtnLayout->addWidget(pbStat["NumData"], 0, 0);
 	smallBtnLayout->addWidget(pbTrig["HypMode"], 0, 1);
 	smallBtnLayout->addWidget(pbLogic["AND"], 0, 2);
-	smallBtnLayout->addWidget(pbPi, 0, 3);
+	smallBtnLayout->addWidget(pbMod, 0, 3);
 	smallBtnLayout->addWidget(NumButtonGroup->find(0xA), 0, 4);
-	smallBtnLayout->addWidget(pbConstant["C1"], 0, 5);
+	smallBtnLayout->addWidget(pbConstant[0], 0, 5);
 
 	smallBtnLayout->addWidget(pbStat["Mean"], 1, 0);
 	smallBtnLayout->addWidget(pbTrig["Sine"], 1, 1);
 	smallBtnLayout->addWidget(pbLogic["OR"], 1, 2);
-	smallBtnLayout->addWidget(pbMod, 1, 3);
+	smallBtnLayout->addWidget(pbReci, 1, 3);
 	smallBtnLayout->addWidget(NumButtonGroup->find(0xB), 1, 4);
-	smallBtnLayout->addWidget(pbConstant["C2"], 1, 5);
+	smallBtnLayout->addWidget(pbConstant[1], 1, 5);
 
 	smallBtnLayout->addWidget(pbStat["StandardDeviation"], 2, 0);
 	smallBtnLayout->addWidget(pbTrig["Cosine"], 2, 1);
 	smallBtnLayout->addWidget(pbLogic["XOR"], 2, 2);
-	smallBtnLayout->addWidget(pbReci, 2, 3);
+	smallBtnLayout->addWidget(pbFactorial, 2, 3);
 	smallBtnLayout->addWidget(NumButtonGroup->find(0xC), 2, 4);
-	smallBtnLayout->addWidget(pbConstant["C3"], 2, 5);
+	smallBtnLayout->addWidget(pbConstant[2], 2, 5);
 
 	smallBtnLayout->addWidget(pbStat["Median"], 3, 0);
 	smallBtnLayout->addWidget(pbTrig["Tangent"], 3, 1);
 	smallBtnLayout->addWidget(pbLogic["LeftShift"], 3, 2);
-	smallBtnLayout->addWidget(pbFactorial, 3, 3);
+	smallBtnLayout->addWidget(pbSquare, 3, 3);
 	smallBtnLayout->addWidget(NumButtonGroup->find(0xD), 3, 4);
-	smallBtnLayout->addWidget(pbConstant["C4"], 3, 5);
+	smallBtnLayout->addWidget(pbConstant[3], 3, 5);
 
 	smallBtnLayout->addWidget(pbStat["InputData"], 4, 0);
 	smallBtnLayout->addWidget(pbExp["Log10"], 4, 1);
 	smallBtnLayout->addWidget(pbLogic["RightShift"], 4, 2);
-	smallBtnLayout->addWidget(pbSquare, 4, 3);
+	smallBtnLayout->addWidget(pbRoot, 4, 3);
 	smallBtnLayout->addWidget(NumButtonGroup->find(0xE), 4, 4);
-	smallBtnLayout->addWidget(pbConstant["C5"], 4, 5);
+	smallBtnLayout->addWidget(pbConstant[4], 4, 5);
 
 	smallBtnLayout->addWidget(pbStat["ClearData"], 5, 0);
 	smallBtnLayout->addWidget(pbExp["LogNatural"], 5, 1);
 	smallBtnLayout->addWidget(pbLogic["One-Complement"], 5, 2);
 	smallBtnLayout->addWidget(pbPower, 5, 3);
 	smallBtnLayout->addWidget(NumButtonGroup->find(0xF), 5, 4);
-	smallBtnLayout->addWidget(pbConstant["C6"],5, 5);
+	smallBtnLayout->addWidget(pbConstant[5], 5, 5);
 
 	smallBtnLayout->setRowStretch(0, 0);
 	smallBtnLayout->setRowStretch(1, 0);
@@ -319,7 +327,7 @@ KCalculator::KCalculator(QWidget *parent, const char *name)
 
 	mFunctionButtonList.append(pbTrig["HypMode"]);
 	mFunctionButtonList.append(pbInv);
-	mFunctionButtonList.append(pbPi);
+	mFunctionButtonList.append(pbRoot);
 	mFunctionButtonList.append(pbTrig["Sine"]);
 	mFunctionButtonList.append(pbPlusMinus);
 	mFunctionButtonList.append(pbTrig["Cosine"]);
@@ -355,13 +363,6 @@ KCalculator::KCalculator(QWidget *parent, const char *name)
 	mOperationButtonList.append(pbLogic["One-Complement"]);
 	mOperationButtonList.append(pbMod);
 
-	mConstButtonList.append(pbConstant["C1"]);
-	mConstButtonList.append(pbConstant["C2"]);
-	mConstButtonList.append(pbConstant["C3"]);
-	mConstButtonList.append(pbConstant["C4"]);
-	mConstButtonList.append(pbConstant["C5"]);
-	mConstButtonList.append(pbConstant["C6"]);
-
 	set_colors();
 	// Show the result in the app's caption in taskbar (wishlist - bug #52858)
 	if (KCalcSettings::captionResult() == true)
@@ -443,7 +444,7 @@ void KCalculator::setupMainActions(void)
 		SLOT(slotLogicshow(bool)));
 
 	actionConstantsShow = new KToggleAction(i18n("&Constants Buttons"), 0,
-					    actionCollection(), "show_constants");
+						actionCollection(), "show_constants");
 	actionConstantsShow->setChecked(true);
 	connect(actionConstantsShow, SIGNAL(toggled(bool)),
 		SLOT(slotConstantsShow(bool)));
@@ -457,9 +458,9 @@ void KCalculator::setupMainActions(void)
 
 	KStdAction::preferences(this, SLOT(showSettings()), actionCollection());
 
-	KStdAction::keyBindings(guiFactory(), SLOT(configureShortcuts()), 
+	KStdAction::keyBindings(guiFactory(), SLOT(configureShortcuts()),
 actionCollection());
-   
+
 }
 
 void KCalculator::setupStatusbar(void)
@@ -473,6 +474,9 @@ void KCalculator::setupStatusbar(void)
 
 	statusBar()->insertFixedItem(" DEG ", 2, true);
 	statusBar()->setItemAlignment(2, AlignCenter);
+
+	statusBar()->insertFixedItem(" \xa0\xa0 ", 3, true); // Memory indicator
+	statusBar()->setItemAlignment(3, AlignCenter);
 }
 
 QWidget* KCalculator::setupNumericKeys(QWidget *parent)
@@ -549,7 +553,7 @@ QWidget* KCalculator::setupNumericKeys(QWidget *parent)
         NumButtonGroup->insert(tmp_pb, 9);
 
 	pbEE = new KCalcButton(thisPage, "EE-Button");
-	pbEE->addMode(ModeNormal, "x<small>10</small><sup>y</sup>",
+	pbEE->addMode(ModeNormal, "x<small>" "\xb7" "10</small><sup>y</sup>",
 			i18n("Exponent"), true);
 	pbEE->setAccel(Key_E);
 	connect(this, SIGNAL(switchShowAccels(bool)),
@@ -648,8 +652,9 @@ QWidget* KCalculator::setupNumericKeys(QWidget *parent)
 	connect(this, SIGNAL(switchShowAccels(bool)),
 		pbMR, SLOT(slotSetAccelDisplayMode(bool)));
 	connect(pbMR, SIGNAL(clicked(void)), SLOT(slotMRclicked(void)));
+        pbMR->setDisabled(true); // At start, there is nothing in memory
 
-	pbMPlusMinus = new KCalcButton("M", mLargePage, "MPlusMinus-Button");
+	pbMPlusMinus = new KCalcButton("M" "\xb1", mLargePage, "MPlusMinus-Button");
 	connect(this, SIGNAL(switchShowAccels(bool)),
 		pbMPlusMinus, SLOT(slotSetAccelDisplayMode(bool)));
 	connect(pbMPlusMinus,SIGNAL(clicked(void)),SLOT(slotMPlusMinusclicked(void)));
@@ -685,7 +690,7 @@ QWidget* KCalculator::setupNumericKeys(QWidget *parent)
 		pbPercent, SLOT(slotSetAccelDisplayMode(bool)));
 	connect(pbPercent, SIGNAL(clicked(void)), SLOT(slotPercentclicked(void)));
 
-	pbPlusMinus = new KCalcButton("", mLargePage, "Sign-Button", i18n("Change sign"));
+	pbPlusMinus = new KCalcButton("\xb1", mLargePage, "Sign-Button", i18n("Change sign"));
 	pbPlusMinus->setAccel(Key_Backslash);
 	connect(this, SIGNAL(switchShowAccels(bool)),
 		pbPlusMinus, SLOT(slotSetAccelDisplayMode(bool)));
@@ -882,10 +887,14 @@ void KCalculator::setupStatisticKeys(QWidget *parent)
 
 	tmp_pb = new KCalcButton(parent, "Stat.NumData-Button");
 	tmp_pb->addMode(ModeNormal, "N", i18n("Number of data entered"));
+	tmp_pb->addMode(ModeInverse, QString::fromUtf8("\xce\xa3")
+			+ "x", i18n("Sum of all data items"));
 	pbStat.insert("NumData", tmp_pb);
         mStatButtonList.append(tmp_pb);
 	connect(this, SIGNAL(switchShowAccels(bool)),
 		tmp_pb, SLOT(slotSetAccelDisplayMode(bool)));
+	connect(this, SIGNAL(switchMode(ButtonModeFlags,bool)),
+		tmp_pb, SLOT(slotSetMode(ButtonModeFlags,bool)));
 	connect(tmp_pb, SIGNAL(clicked(void)), SLOT(slotStatNumclicked(void)));
 
 	tmp_pb = new KCalcButton(parent, "Stat.Median-Button");
@@ -899,10 +908,15 @@ void KCalculator::setupStatisticKeys(QWidget *parent)
 
 	tmp_pb = new KCalcButton(parent, "Stat.Mean-Button");
 	tmp_pb->addMode(ModeNormal, "Mea", i18n("Mean"));
+	tmp_pb->addMode(ModeInverse, QString::fromUtf8("\xce\xa3")
+			+ "x<sup>2</sup>",
+			i18n("Sum of all data items squared"), true);
 	pbStat.insert("Mean", tmp_pb);
         mStatButtonList.append(tmp_pb);
 	connect(this, SIGNAL(switchShowAccels(bool)),
 		tmp_pb, SLOT(slotSetAccelDisplayMode(bool)));
+	connect(this, SIGNAL(switchMode(ButtonModeFlags,bool)),
+		tmp_pb, SLOT(slotSetMode(ButtonModeFlags,bool)));
 	connect(tmp_pb, SIGNAL(clicked(void)), SLOT(slotStatMeanclicked(void)));
 
 	tmp_pb = new KCalcButton(parent, "Stat.StandardDeviation-Button");
@@ -915,10 +929,13 @@ void KCalculator::setupStatisticKeys(QWidget *parent)
 
 	tmp_pb = new KCalcButton(parent, "Stat.DataInput-Button");
 	tmp_pb->addMode(ModeNormal, "Dat", i18n("Enter data"));
+	tmp_pb->addMode(ModeInverse, "CDat", i18n("Delete last data item"));
 	pbStat.insert("InputData", tmp_pb);
         mStatButtonList.append(tmp_pb);
 	connect(this, SIGNAL(switchShowAccels(bool)),
 		tmp_pb, SLOT(slotSetAccelDisplayMode(bool)));
+	connect(this, SIGNAL(switchMode(ButtonModeFlags,bool)),
+		tmp_pb, SLOT(slotSetMode(ButtonModeFlags,bool)));
 	connect(tmp_pb, SIGNAL(clicked(void)), SLOT(slotStatDataInputclicked(void)));
 
 	tmp_pb = new KCalcButton(parent, "Stat.ClearData-Button");
@@ -934,56 +951,79 @@ void KCalculator::setupConstantsKeys(QWidget *parent)
 {
 	Q_CHECK_PTR(parent);
 
-	KCalcButton *tmp_pb;
-	tmp_pb = new KCalcButton("C1", parent, "Constant C1 - Button");
+	ConstButtonGroup = new QButtonGroup(0, "Const-Button-Group");
+	connect(ConstButtonGroup, SIGNAL(clicked(int)), SLOT(slotConstclicked(int)));
+
+
+	KCalcConstButton *tmp_pb;
+	tmp_pb = new KCalcConstButton(parent, 0, "C1");
 	tmp_pb->setAccel(ALT + Key_1);
-	pbConstant.insert("C1", tmp_pb);
-	mConstButtonList.append(tmp_pb);
+	pbConstant[0] = tmp_pb;
 	connect(this, SIGNAL(switchShowAccels(bool)),
-                tmp_pb, SLOT(slotSetAccelDisplayMode(bool)));
-	connect(tmp_pb, SIGNAL(clicked(void)), SLOT(slotC1clicked(void)));
+		tmp_pb, SLOT(slotSetAccelDisplayMode(bool)));
+	connect(this, SIGNAL(switchMode(ButtonModeFlags,bool)),
+		tmp_pb, SLOT(slotSetMode(ButtonModeFlags,bool)));
+	ConstButtonGroup->insert(tmp_pb, 0);
 
-	tmp_pb = new KCalcButton("C2", parent, "Constant C2 - Button");
+	tmp_pb = new KCalcConstButton(parent, 1, "C2");
         tmp_pb->setAccel(ALT + Key_2);
-	pbConstant.insert("C2", tmp_pb);
-	mConstButtonList.append(tmp_pb);
+	pbConstant[1] = tmp_pb;
 	connect(this, SIGNAL(switchShowAccels(bool)),
                 tmp_pb, SLOT(slotSetAccelDisplayMode(bool)));
-	connect(tmp_pb, SIGNAL(clicked(void)), SLOT(slotC2clicked(void)));
+	connect(this, SIGNAL(switchMode(ButtonModeFlags,bool)),
+		tmp_pb, SLOT(slotSetMode(ButtonModeFlags,bool)));
+	ConstButtonGroup->insert(tmp_pb, 1);
 
-	tmp_pb = new KCalcButton("C3", parent, "Constant C3 - Button");
+	tmp_pb = new KCalcConstButton(parent, 2, "C3");
         tmp_pb->setAccel(ALT + Key_3);
-	pbConstant.insert("C3", tmp_pb);
-	mConstButtonList.append(tmp_pb);
+	pbConstant[2] = tmp_pb;
 	connect(this, SIGNAL(switchShowAccels(bool)),
                 tmp_pb, SLOT(slotSetAccelDisplayMode(bool)));
-	connect(tmp_pb, SIGNAL(clicked(void)), SLOT(slotC3clicked(void)));
+	connect(this, SIGNAL(switchMode(ButtonModeFlags,bool)),
+		tmp_pb, SLOT(slotSetMode(ButtonModeFlags,bool)));
+	ConstButtonGroup->insert(tmp_pb, 2);
 
-	tmp_pb = new KCalcButton("C4", parent, "Constant C4 - Button");
+	tmp_pb = new KCalcConstButton(parent, 3, "C4");
         tmp_pb->setAccel(ALT + Key_4);
-	pbConstant.insert("C4", tmp_pb);
-	mConstButtonList.append(tmp_pb);
+	pbConstant[3] = tmp_pb;
 	connect(this, SIGNAL(switchShowAccels(bool)),
                 tmp_pb, SLOT(slotSetAccelDisplayMode(bool)));
-	connect(tmp_pb, SIGNAL(clicked(void)), SLOT(slotC4clicked(void)));
+	connect(this, SIGNAL(switchMode(ButtonModeFlags,bool)),
+		tmp_pb, SLOT(slotSetMode(ButtonModeFlags,bool)));
+	ConstButtonGroup->insert(tmp_pb, 3);
 
-	tmp_pb = new KCalcButton("C5", parent, "Constant C5 - Button");
+	tmp_pb = new KCalcConstButton(parent, 4, "C5");
         tmp_pb->setAccel(ALT + Key_5);
-	pbConstant.insert("C5", tmp_pb);
-	mConstButtonList.append(tmp_pb);
+	pbConstant[4] = tmp_pb;
 	connect(this, SIGNAL(switchShowAccels(bool)),
                 tmp_pb, SLOT(slotSetAccelDisplayMode(bool)));
-	connect(tmp_pb, SIGNAL(clicked(void)), SLOT(slotC5clicked(void)));
+	connect(this, SIGNAL(switchMode(ButtonModeFlags,bool)),
+		tmp_pb, SLOT(slotSetMode(ButtonModeFlags,bool)));
+	ConstButtonGroup->insert(tmp_pb, 4);
 
-	tmp_pb = new KCalcButton("C6", parent, "Constant C6 - Button");
+	tmp_pb = new KCalcConstButton(parent, 5, "C6");
         tmp_pb->setAccel(ALT + Key_6);
-	pbConstant.insert("C6", tmp_pb);
-	mConstButtonList.append(tmp_pb);
+	pbConstant[5]  = tmp_pb;
 	connect(this, SIGNAL(switchShowAccels(bool)),
                 tmp_pb, SLOT(slotSetAccelDisplayMode(bool)));
-	connect(tmp_pb, SIGNAL(clicked(void)), SLOT(slotC6clicked(void)));
+	connect(this, SIGNAL(switchMode(ButtonModeFlags,bool)),
+		tmp_pb, SLOT(slotSetMode(ButtonModeFlags,bool)));
+	ConstButtonGroup->insert(tmp_pb, 5);
 
 	changeButtonNames();
+
+	// add menu with scientific constants
+	KCalcConstMenu *tmp_menu = new KCalcConstMenu(this);
+	menuBar()->insertItem(i18n("&Constants"), tmp_menu, -1, 2);
+	connect(tmp_menu, SIGNAL(activated(int)), this,
+		SLOT(slotConstantToDisplay(int)));
+}
+
+void KCalculator::slotConstantToDisplay(int constant)
+{
+	calc_display->setAmount(KCalcConstMenu::Constants[constant].value);
+
+	UpdateDisplay(false);
 }
 
 void KCalculator::updateGeometry(void)
@@ -1138,12 +1178,6 @@ void KCalculator::keyPressEvent(QKeyEvent *e)
     if ( ( e->state() & KeyButtonMask ) == 0 || ( e->state() & ShiftButton ) ) {
 	switch (e->key())
 	{
-	case Key_Up:
-		history_prev();
-		break;
-	case Key_Down:
-		history_next();
-		break;
 	case Key_Next:
 		pbAC->animateClick();
 		break;
@@ -1177,22 +1211,29 @@ void KCalculator::keyReleaseEvent(QKeyEvent *e)
 
 void KCalculator::slotAngleSelected(int number)
 {
+	pbAngleChoose->popup()->setItemChecked(0, false);
+	pbAngleChoose->popup()->setItemChecked(1, false);
+	pbAngleChoose->popup()->setItemChecked(2, false);
+
 	switch(number)
 	{
 	case 0:
-		core.SetAngleMode(ANG_DEGREE);
+		_angle_mode = DegMode;
 		statusBar()->changeItem("DEG", 2);
+		pbAngleChoose->popup()->setItemChecked(0, true);
 		break;
 	case 1:
-		core.SetAngleMode(ANG_RADIAN);
+		_angle_mode = RadMode;
 		statusBar()->changeItem("RAD", 2);
+		pbAngleChoose->popup()->setItemChecked(1, true);
 		break;
 	case 2:
-		core.SetAngleMode(ANG_GRADIENT);
+		_angle_mode = GradMode;
 		statusBar()->changeItem("GRA", 2);
+		pbAngleChoose->popup()->setItemChecked(2, true);
 		break;
 	default: // we shouldn't ever end up here
-		core.SetAngleMode(ANG_RADIAN);
+		_angle_mode = RadMode;
 	}
 }
 
@@ -1201,13 +1242,6 @@ void KCalculator::slotEEclicked(void)
 	calc_display->newCharacter('e');
 }
 
-void KCalculator::slotPiclicked(void)
-{
-	calc_display->setAmount(pi);
-
-	UpdateDisplay(false);
-}
-
 void KCalculator::slotInvtoggled(bool flag)
 {
 	inverse = flag;
@@ -1229,7 +1263,7 @@ void KCalculator::slotHyptoggled(bool flag)
 	// toggle between hyperbolic and standart trig functions
 	hyp_mode = flag;
 
-	emit switchMode(ModeHyperbolic, flag); 
+	emit switchMode(ModeHyperbolic, flag);
 }
 
 
@@ -1237,7 +1271,7 @@ void KCalculator::slotHyptoggled(bool flag)
 void KCalculator::slotMRclicked(void)
 {
 	// temp. work-around
-	calc_display->Reset();
+	calc_display->sendEvent(KCalcDisplay::EventReset);
 
 	calc_display->setAmount(memory_num);
 	UpdateDisplay(false);
@@ -1262,9 +1296,31 @@ void KCalculator::slotSinclicked(void)
 	{
 		// sine or arcsine
 		if (!inverse)
-			core.Sin(calc_display->getAmount());
+			switch(_angle_mode)
+			{
+			case DegMode:
+				core.SinDeg(calc_display->getAmount());
+				break;
+			case RadMode:
+				core.SinRad(calc_display->getAmount());
+				break;
+			case GradMode:
+				core.SinGrad(calc_display->getAmount());
+				break;
+			}
 		else
-			core.ArcSin(calc_display->getAmount());
+			switch(_angle_mode)
+			{
+			case DegMode:
+				core.ArcSinDeg(calc_display->getAmount());
+				break;
+			case RadMode:
+				core.ArcSinRad(calc_display->getAmount());
+				break;
+			case GradMode:
+				core.ArcSinGrad(calc_display->getAmount());
+				break;
+			}
 	}
 
 	UpdateDisplay(true);
@@ -1274,7 +1330,7 @@ void KCalculator::slotPlusMinusclicked(void)
 {
 	// display can only change sign, when in input mode, otherwise we
 	// need the core to do this.
-	if (!calc_display->changeSign())
+	if (!calc_display->sendEvent(KCalcDisplay::EventChangeSign))
 	{
 	    core.InvertSign(calc_display->getAmount());
 	    UpdateDisplay(true);
@@ -1283,12 +1339,15 @@ void KCalculator::slotPlusMinusclicked(void)
 
 void KCalculator::slotMPlusMinusclicked(void)
 {
-	EnterEqual();
+	bool tmp_inverse = inverse; // store this, because next command deletes inverse
+	EnterEqual(); // finish calculation so far, to store result into MEM
 
-	if (!inverse)	memory_num += calc_display->getAmount();
+	if (!tmp_inverse)	memory_num += calc_display->getAmount();
 	else 			memory_num -= calc_display->getAmount();
 
 	pbInv->setOn(false);
+	statusBar()->changeItem("M",3);
+        pbMR->setEnabled(true);
 }
 
 void KCalculator::slotCosclicked(void)
@@ -1305,9 +1364,31 @@ void KCalculator::slotCosclicked(void)
 	{
 		// cosine or arccosine
 		if (!inverse)
-			core.Cos(calc_display->getAmount());
+			switch(_angle_mode)
+			{
+			case DegMode:
+				core.CosDeg(calc_display->getAmount());
+				break;
+			case RadMode:
+				core.CosRad(calc_display->getAmount());
+				break;
+			case GradMode:
+				core.CosGrad(calc_display->getAmount());
+				break;
+			}
 		else
-			core.ArcCos(calc_display->getAmount());
+			switch(_angle_mode)
+			{
+			case DegMode:
+				core.ArcCosDeg(calc_display->getAmount());
+				break;
+			case RadMode:
+				core.ArcCosRad(calc_display->getAmount());
+				break;
+			case GradMode:
+				core.ArcCosGrad(calc_display->getAmount());
+				break;
+			}
 	}
 
 	UpdateDisplay(true);
@@ -1333,9 +1414,31 @@ void KCalculator::slotTanclicked(void)
 	{
 		// tan or arctan
 		if (!inverse)
-			core.Tangens(calc_display->getAmount());
+			switch(_angle_mode)
+			{
+			case DegMode:
+				core.TangensDeg(calc_display->getAmount());
+				break;
+			case RadMode:
+				core.TangensRad(calc_display->getAmount());
+				break;
+			case GradMode:
+				core.TangensGrad(calc_display->getAmount());
+				break;
+			}
 		else
-			core.ArcTangens(calc_display->getAmount());
+			switch(_angle_mode)
+			{
+			case DegMode:
+				core.ArcTangensDeg(calc_display->getAmount());
+				break;
+			case RadMode:
+				core.ArcTangensRad(calc_display->getAmount());
+				break;
+			case GradMode:
+				core.ArcTangensGrad(calc_display->getAmount());
+				break;
+			}
 	}
 
 	UpdateDisplay(true);
@@ -1364,7 +1467,17 @@ void KCalculator::slotSquareclicked(void)
 	if (!inverse)
 		core.Square(calc_display->getAmount());
 	else
+		core.Cube(calc_display->getAmount());
+
+	UpdateDisplay(true);
+}
+
+void KCalculator::slotRootclicked(void)
+{
+	if (!inverse)
 		core.SquareRoot(calc_display->getAmount());
+	else
+		core.CubeRoot(calc_display->getAmount());
 
 	UpdateDisplay(true);
 }
@@ -1383,16 +1496,18 @@ void KCalculator::slotPowerclicked(void)
 {
 	if (inverse)
 	{
-		core.InvPower(calc_display->getAmount());
+		core.enterOperation(calc_display->getAmount(),
+				    CalcEngine::FUNC_PWR_ROOT);
 		pbInv->setOn(false);
 	}
 	else
 	{
-		core.Power(calc_display->getAmount());
+		core.enterOperation(calc_display->getAmount(),
+				    CalcEngine::FUNC_POWER);
 	}
 	// temp. work-around
 	CALCAMNT tmp_num = calc_display->getAmount();
-	calc_display->Reset();
+	calc_display->sendEvent(KCalcDisplay::EventReset);
 	calc_display->setAmount(tmp_num);
 	UpdateDisplay(false);
 }
@@ -1400,17 +1515,19 @@ void KCalculator::slotPowerclicked(void)
 void KCalculator::slotMCclicked(void)
 {
 	memory_num		= 0;
+	statusBar()->changeItem(" \xa0\xa0 ",3);
+        pbMR->setDisabled(true);
 }
 
 void KCalculator::slotClearclicked(void)
 {
-	calc_display->clearLastInput();
+	calc_display->sendEvent(KCalcDisplay::EventClear);
 }
 
 void KCalculator::slotACclicked(void)
 {
 	core.Reset();
-	calc_display->Reset();
+	calc_display->sendEvent(KCalcDisplay::EventReset);
 
 	UpdateDisplay(true);
 }
@@ -1432,63 +1549,72 @@ void KCalculator::slotParenCloseclicked(void)
 
 void KCalculator::slotANDclicked(void)
 {
-	core.And(calc_display->getAmount());
+	core.enterOperation(calc_display->getAmount(),
+			    CalcEngine::FUNC_AND);
 
 	UpdateDisplay(true);
 }
 
 void KCalculator::slotXclicked(void)
 {
-	core.Multiply(calc_display->getAmount());
+	core.enterOperation(calc_display->getAmount(),
+			    CalcEngine::FUNC_MULTIPLY);
 
 	UpdateDisplay(true);
 }
 
 void KCalculator::slotDivisionclicked(void)
 {
-	core.Divide(calc_display->getAmount());
+	core.enterOperation(calc_display->getAmount(),
+			    CalcEngine::FUNC_DIVIDE);
 
 	UpdateDisplay(true);
 }
 
 void KCalculator::slotORclicked(void)
 {
-	core.Or(calc_display->getAmount());
+	core.enterOperation(calc_display->getAmount(),
+			    CalcEngine::FUNC_OR);
 
 	UpdateDisplay(true);
 }
 
 void KCalculator::slotXORclicked(void)
 {
-	core.Xor(calc_display->getAmount());
+	core.enterOperation(calc_display->getAmount(),
+			    CalcEngine::FUNC_XOR);
 
 	UpdateDisplay(true);
 }
 
 void KCalculator::slotPlusclicked(void)
 {
-	core.Plus(calc_display->getAmount());
+	core.enterOperation(calc_display->getAmount(),
+			    CalcEngine::FUNC_ADD);
 
 	UpdateDisplay(true);
 }
 
 void KCalculator::slotMinusclicked(void)
 {
-	core.Minus(calc_display->getAmount());
+	core.enterOperation(calc_display->getAmount(),
+			    CalcEngine::FUNC_SUBTRACT);
 
 	UpdateDisplay(true);
 }
 
 void KCalculator::slotLeftShiftclicked(void)
 {
-	core.ShiftLeft(calc_display->getAmount());
+	core.enterOperation(calc_display->getAmount(),
+			    CalcEngine::FUNC_LSH);
 
 	UpdateDisplay(true);
 }
 
 void KCalculator::slotRightShiftclicked(void)
 {
-	core.ShiftRight(calc_display->getAmount());
+	core.enterOperation(calc_display->getAmount(),
+			    CalcEngine::FUNC_RSH);
 
 	UpdateDisplay(true);
 }
@@ -1500,7 +1626,8 @@ void KCalculator::slotPeriodclicked(void)
 
 void KCalculator::EnterEqual()
 {
-	core.Equal(calc_display->getAmount());
+	core.enterOperation(calc_display->getAmount(),
+			    CalcEngine::FUNC_EQUAL);
 
 	UpdateDisplay(true, true);
 }
@@ -1512,7 +1639,8 @@ void KCalculator::slotEqualclicked(void)
 
 void KCalculator::slotPercentclicked(void)
 {
-	core.Percent(calc_display->getAmount());
+	core.enterOperation(calc_display->getAmount(),
+			    CalcEngine::FUNC_PERCENT);
 
 	UpdateDisplay(true);
 }
@@ -1527,9 +1655,11 @@ void KCalculator::slotNegateclicked(void)
 void KCalculator::slotModclicked(void)
 {
 	if (inverse)
-		core.InvMod(calc_display->getAmount());
+		core.enterOperation(calc_display->getAmount(),
+				    CalcEngine::FUNC_INTDIV);
 	else
-		core.Mod(calc_display->getAmount());
+		core.enterOperation(calc_display->getAmount(),
+				    CalcEngine::FUNC_MOD);
 
 	UpdateDisplay(true);
 }
@@ -1626,45 +1756,23 @@ void KCalculator::slotStatClearDataclicked(void)
 	}
 }
 
-void KCalculator::slotC1clicked(void)
+void KCalculator::slotConstclicked(int button)
 {
-	//set the display to the configured value of Constant C1
-	calc_display->setAmount(KCalcSettings::valueConstant1().toDouble());
-
-	UpdateDisplay(false);
-}
-void KCalculator::slotC2clicked(void)
-{
-	//set the display to the configured value of Constant C2
-	calc_display->setAmount( KCalcSettings::valueConstant2().toDouble());
-
-	UpdateDisplay(false);
-}
-void KCalculator::slotC3clicked(void)
-{
-	//set the display to the configured value of Constant C3
-	calc_display->setAmount(KCalcSettings::valueConstant3().toDouble());
-
-	UpdateDisplay(false);
-}
-void KCalculator::slotC4clicked(void)
-{
-	//set the display to the configured value of Constant C4
-	calc_display->setAmount(KCalcSettings::valueConstant4().toDouble());
-
-	UpdateDisplay(false);
-}
-void KCalculator::slotC5clicked(void)
-{
-	//set the display to the configured value of Constant C5
-	calc_display->setAmount(KCalcSettings::valueConstant5().toDouble());
-
-	UpdateDisplay(false);
-}
-void KCalculator::slotC6clicked(void)
-{;
-	//set the display to the configured value of Constant C6
-	calc_display->setAmount(KCalcSettings::valueConstant6().toDouble());
+	if(!inverse)
+	{
+		//set the display to the configured value of Constant Button
+		calc_display->setAmount(pbConstant[button]->constant());
+	}
+	else
+	{
+		pbInv->setOn(false);
+		KCalcSettings::setValueConstant(button, calc_display->text());
+		// below set new tooltip
+		pbConstant[button]->setLabelAndTooltip();
+		// work around: after storing a number, pressing a digit should start
+		// a new number
+		calc_display->setAmount(calc_display->getAmount());
+	}
 
 	UpdateDisplay(false);
 }
@@ -1698,21 +1806,50 @@ void KCalculator::showSettings()
 	fontLayout->addWidget(mFontChooser);
 	dialog->addPage(fontWidget, i18n("Font"), "fonts", i18n("Select Display Font"));
 
+	// color settings
+
 	Colors *color = new Colors(0, "Color");
 
 	dialog->addPage(color, i18n("Colors"), "colors", i18n("Button & Display Colors"));
 
+	// constant settings
+
 	Constants *constant = new Constants(0, "Constant" );
-        KDoubleValidator *valid = new KDoubleValidator( this );
-        constant->kcfg_valueConstant1->setValidator( valid );
-        constant->kcfg_valueConstant2->setValidator( valid );
-        constant->kcfg_valueConstant3->setValidator( valid );
-        constant->kcfg_valueConstant4->setValidator( valid );
-        constant->kcfg_valueConstant5->setValidator( valid );
-        constant->kcfg_valueConstant6->setValidator( valid );
+	tmp_const = constant;
+
+	KCalcConstMenu *tmp_menu = new KCalcConstMenu(this);
+	connect(tmp_menu, SIGNAL(activated(int)),
+		SLOT(slotChooseScientificConst0(int)));
+	(constant->kPushButton0)->setPopup(tmp_menu);
+
+	tmp_menu = new KCalcConstMenu(this);
+	connect(tmp_menu, SIGNAL(activated(int)),
+		SLOT(slotChooseScientificConst1(int)));
+	(constant->kPushButton1)->setPopup(tmp_menu);
+
+	tmp_menu = new KCalcConstMenu(this);
+	connect(tmp_menu, SIGNAL(activated(int)),
+		SLOT(slotChooseScientificConst2(int)));
+	(constant->kPushButton2)->setPopup(tmp_menu);
+
+	tmp_menu = new KCalcConstMenu(this);
+	connect(tmp_menu, SIGNAL(activated(int)),
+		SLOT(slotChooseScientificConst3(int)));
+	(constant->kPushButton3)->setPopup(tmp_menu);
+
+	tmp_menu = new KCalcConstMenu(this);
+	connect(tmp_menu, SIGNAL(activated(int)),
+		SLOT(slotChooseScientificConst4(int)));
+	(constant->kPushButton4)->setPopup(tmp_menu);
+
+	tmp_menu = new KCalcConstMenu(this);
+	connect(tmp_menu, SIGNAL(activated(int)),
+		SLOT(slotChooseScientificConst5(int)));
+	(constant->kPushButton5)->setPopup(tmp_menu);
 
 	dialog->addPage(constant, i18n("Constants"), "constants");
 
+
 	// When the user clicks OK or Apply we want to update our settings.
 	connect(dialog, SIGNAL(settingsChanged()), SLOT(updateSettings()));
 
@@ -1720,6 +1857,53 @@ void KCalculator::showSettings()
 	dialog->show();
 }
 
+
+// these 6 slots are just a quick hack, instead of setting the
+// TextEdit fields in the configuration dialog, we are setting the
+// Settingvalues themselves!!
+void KCalculator::slotChooseScientificConst0(int option)
+{
+  (tmp_const->kcfg_valueConstant0)->setText(KCalcConstMenu::Constants[option].value);
+
+  (tmp_const->kcfg_nameConstant0)->setText(KCalcConstMenu::Constants[option].label);
+}
+
+void KCalculator::slotChooseScientificConst1(int option)
+{
+  (tmp_const->kcfg_valueConstant1)->setText(KCalcConstMenu::Constants[option].value);
+
+  (tmp_const->kcfg_nameConstant1)->setText(KCalcConstMenu::Constants[option].label);
+}
+
+void KCalculator::slotChooseScientificConst2(int option)
+{
+  (tmp_const->kcfg_valueConstant2)->setText(KCalcConstMenu::Constants[option].value);
+
+  (tmp_const->kcfg_nameConstant2)->setText(KCalcConstMenu::Constants[option].label);
+}
+
+void KCalculator::slotChooseScientificConst3(int option)
+{
+  (tmp_const->kcfg_valueConstant3)->setText(KCalcConstMenu::Constants[option].value);
+
+  (tmp_const->kcfg_nameConstant3)->setText(KCalcConstMenu::Constants[option].label);
+}
+
+void KCalculator::slotChooseScientificConst4(int option)
+{
+  (tmp_const->kcfg_valueConstant4)->setText(KCalcConstMenu::Constants[option].value);
+
+  (tmp_const->kcfg_nameConstant4)->setText(KCalcConstMenu::Constants[option].label);
+}
+
+void KCalculator::slotChooseScientificConst5(int option)
+{
+  (tmp_const->kcfg_valueConstant5)->setText(KCalcConstMenu::Constants[option].value);
+
+  (tmp_const->kcfg_nameConstant5)->setText(KCalcConstMenu::Constants[option].label);
+}
+
+
 void KCalculator::slotStatshow(bool toggled)
 {
 	if(toggled)
@@ -1834,84 +2018,39 @@ void KCalculator::slotConstantsShow(bool toggled)
 {
 	if(toggled)
 	{
-		pbConstant["C1"]->show();
-		pbConstant["C2"]->show();
-		pbConstant["C3"]->show();
-		pbConstant["C4"]->show();
-		pbConstant["C5"]->show();
-		pbConstant["C6"]->show();
+		pbConstant[0]->show();
+		pbConstant[1]->show();
+		pbConstant[2]->show();
+		pbConstant[3]->show();
+		pbConstant[4]->show();
+		pbConstant[5]->show();
 
 	}
 	else
 	{
-		pbConstant["C1"]->hide();
-		pbConstant["C2"]->hide();
-		pbConstant["C3"]->hide();
-		pbConstant["C4"]->hide();
-		pbConstant["C5"]->hide();
-		pbConstant["C6"]->hide();
+		pbConstant[0]->hide();
+		pbConstant[1]->hide();
+		pbConstant[2]->hide();
+		pbConstant[3]->hide();
+		pbConstant[4]->hide();
+		pbConstant[5]->hide();
 	}
 	adjustSize();
 	setFixedSize(sizeHint());
 	KCalcSettings::setShowConstants(toggled);
 }
-// This function is for setting the constant names configured in the kcalc settings menue. If the user doesn't
-// enter a name for the constant C1 to C6 is used.
+
+// This function is for setting the constant names configured in the
+// kcalc settings menu. If the user doesn't enter a name for the
+// constant C1 to C6 is used.
 void KCalculator::changeButtonNames()
 {
-	if(KCalcSettings::nameConstant1().isEmpty() )
-	{
-		pbConstant["C1"]->setText("C1");
-	}
-	else
-	{
-		pbConstant["C1"]->setText(KCalcSettings::nameConstant1());
-	}
-
-	if(KCalcSettings::nameConstant2().isEmpty() )
-	{
-		pbConstant["C2"]->setText("C2");
-	}
-	else
-	{
-		pbConstant["C2"]->setText(KCalcSettings::nameConstant2());
-	}
-
-	if(KCalcSettings::nameConstant3().isEmpty() )
-	{
-		pbConstant["C3"]->setText("C3");
-	}
-	else
-	{
-		pbConstant["C3"]->setText(KCalcSettings::nameConstant3());
-	}
-
-	if(KCalcSettings::nameConstant4().isEmpty() )
-	{
-		pbConstant["C4"]->setText("C4");
-	}
-	else
-	{
-		pbConstant["C4"]->setText(KCalcSettings::nameConstant4());
-	}
-
-	if(KCalcSettings::nameConstant5().isEmpty() )
-	{
-		pbConstant["C5"]->setText("C5");
-	}
-	else
-	{
-		pbConstant["C5"]->setText(KCalcSettings::nameConstant5());
-	}
-
-	if(KCalcSettings::nameConstant6().isEmpty() )
-	{
-		pbConstant["C6"]->setText("C6");
-	}
-	else
-	{
-		pbConstant["C6"]->setText(KCalcSettings::nameConstant6());
-	}
+	pbConstant[0]->setLabelAndTooltip();
+	pbConstant[1]->setLabelAndTooltip();
+	pbConstant[2]->setLabelAndTooltip();
+	pbConstant[3]->setLabelAndTooltip();
+	pbConstant[4]->setLabelAndTooltip();
+	pbConstant[5]->setLabelAndTooltip();
 }
 
 void KCalculator::slotShowAll(void)
@@ -1934,12 +2073,6 @@ void KCalculator::slotHideAll(void)
 	if(actionConstantsShow->isChecked()) actionConstantsShow->activate();
 }
 
-void KCalculator::RefreshCalculator()
-{
-	pbInv->setOn(false);
-	calc_display->Reset();
-}
-
 void KCalculator::updateSettings()
 {
 	changeButtonNames();
@@ -1971,7 +2104,7 @@ void KCalculator::updateSettings()
 }
 
 void KCalculator::UpdateDisplay(bool get_amount_from_core,
-				 bool store_result_in_history)
+				bool store_result_in_history)
 {
 	if(get_amount_from_core)
 	{
@@ -2039,18 +2172,6 @@ void KCalculator::set_precision()
 	UpdateDisplay(false);
 }
 
-void KCalculator::history_next()
-{
-	if(!calc_display->history_next()  &&  KCalcSettings::beep())
-		KNotifyClient::beep();
-}
-
-void KCalculator::history_prev()
-{
-	if(!calc_display->history_prev()  &&  KCalcSettings::beep())
-		KNotifyClient::beep();
-}
-
 bool KCalculator::eventFilter(QObject *o, QEvent *e)
 {
 	if(e->type() == QEvent::DragEnter)
@@ -2132,7 +2253,7 @@ bool KCalculator::eventFilter(QObject *o, QEvent *e)
 #include "kcalc.moc"
 
 
-extern "C" int kdemain(int argc, char *argv[])
+extern "C" KDE_EXPORT int kdemain(int argc, char *argv[])
 {
         QString precisionStatement;
 
@@ -2160,9 +2281,12 @@ extern "C" int kdemain(int argc, char *argv[])
 	aboutData.addAuthor("Evan Teran", 0, "emt3734@rit.edu");
 	aboutData.addAuthor("Espen Sand", 0, "espen@kde.org");
 	aboutData.addAuthor("Chris Howells", 0, "howells@kde.org");
-    aboutData.addAuthor("Aaron J. Seigo", 0, "aseigo@olympusproject.org");
-    aboutData.addAuthor("Charles Samuels", 0, "charles@altair.dhs.org");
-    aboutData.addAuthor("Klaus Niederkrüger", 0, "kniederk@math.uni-koeln.de");
+	aboutData.addAuthor("Aaron J. Seigo", 0, "aseigo@olympusproject.org");
+	aboutData.addAuthor("Charles Samuels", 0, "charles@altair.dhs.org");
+	/* Klaus Niederkrueger */
+	aboutData.addAuthor("Klaus Niederkr" "\xc3\xbc" "ger", 0, "kniederk@math.uni-koeln.de");
+	/* Rene Merou */
+	aboutData.addAuthor("Ren" "\xc3\xa9" " M" "\xc3\xa9"  "rou", 0, "ochominutosdearco@yahoo.es");
 	KCmdLineArgs::init(argc, argv, &aboutData);
 
 	KApplication app;
