@@ -51,7 +51,10 @@ K_EXPORT_COMPONENT_FACTORY(kcmlirc, theFactory("kcmlirc"))
 
 KCMLirc::KCMLirc(QWidget *parent, const char *name, QStringList /*args*/) : DCOPObject("KCMLirc"), KCModule(parent, name)
 {
-    KGlobal::locale()->insertCatalogue( "kdelirc" );
+	KGlobal::locale()->insertCatalogue( "kcmlirc" );
+	setAboutData(new KAboutData("kcmlirc", I18N_NOOP("KDE Lirc"), VERSION, I18N_NOOP("The KDE IR Remote Control System"), KAboutData::License_GPL_V2, "Copyright (c)2003 Gav Wood", I18N_NOOP("Use this to configure KDE's infrared remote control system in order to control any KDE application with your infrared remote control."), "http://www.kde.org"));
+	setButtons(KCModule::Help);
+	setQuickHelp(i18n("<h1>Remote Controls</h1><p>This module allows you to configure bindings between your remote controls and KDE applications. Simply select your remote control and click Add under the Actions/Buttons list. If you want KDE to attempt to automatically assign buttons to a supported application's actions, try clicking the Auto-Populate button.</p><p>To view the recognised applications and remote controls, simply select the <em>Loaded Extensions</em> tab.</p>"));
 	bool ok;
 	KApplication::kApplication()->dcopClient()->remoteInterfaces("irkick", "IRKick", &ok);
 	if(!ok)
@@ -286,7 +289,7 @@ void KCMLirc::slotAddMode()
 		remoteMap[a] = modeMap[i].remote();
 		if(i == tr) { a->setSelected(true); theDialog.theRemotes->setCurrentItem(a); }
 	}
-	if(theDialog.exec() == QDialog::Accepted && theDialog.theRemotes->selectedItem() && theDialog.theName->text() != "")
+	if(theDialog.exec() == QDialog::Accepted && theDialog.theRemotes->selectedItem() && !theDialog.theName->text().isEmpty())
 	{
 		allModes.add(Mode(remoteMap[theDialog.theRemotes->selectedItem()], theDialog.theName->text()));
 		updateModes();
@@ -302,8 +305,8 @@ void KCMLirc::slotEditMode()
 
 	Mode &mode = modeMap[theKCMLircBase->theModes->selectedItem()];
 	theDialog.theName->setEnabled(theKCMLircBase->theModes->selectedItem()->parent());
-	theDialog.theName->setText(mode.name() == "" ? mode.remoteName() : mode.name());
-	if(mode.iconFile() != QString::null)
+	theDialog.theName->setText(mode.name().isEmpty() ? mode.remoteName() : mode.name());
+	if(!mode.iconFile().isNull())
 		theDialog.theIcon->setIcon(mode.iconFile());
 	else
 		theDialog.theIcon->resetIcon();
@@ -312,9 +315,9 @@ void KCMLirc::slotEditMode()
 
 	if(theDialog.exec() == QDialog::Accepted)
 	{	kdDebug() << "Setting icon : " << theDialog.theIcon->icon() << endl;
-		mode.setIconFile(theDialog.theIcon->icon() == "" ? QString::null : theDialog.theIcon->icon());
+		mode.setIconFile(theDialog.theIcon->icon().isEmpty() ? QString::null : theDialog.theIcon->icon());
 		allModes.updateMode(mode);
-		if(mode.name() != "")
+		if(!mode.name().isEmpty())
 		{	allActions.renameMode(mode, theDialog.theName->text());
 			allModes.rename(mode, theDialog.theName->text());
 		}
@@ -373,9 +376,9 @@ void KCMLirc::updateActions()
 	if(!theKCMLircBase->theModes->selectedItem()) { updateActionsStatus(0); return; }
 
 	Mode m = modeMap[theKCMLircBase->theModes->selectedItem()];
-	theKCMLircBase->theModeLabel->setText(m.remoteName() + ": " + (m.name() == "" ? i18n("Actions <i>always</i> available") : i18n("Actions available only in mode <b>%1</b>").arg(m.name())));
+	theKCMLircBase->theModeLabel->setText(m.remoteName() + ": " + (m.name().isEmpty() ? i18n("Actions <i>always</i> available") : i18n("Actions available only in mode <b>%1</b>").arg(m.name())));
 	IRAItList l = allActions.findByMode(m);
-	for(IRAItList::iterator i = l.begin(); i != l.end(); i++)
+	for(IRAItList::iterator i = l.begin(); i != l.end(); ++i)
 	{	QListViewItem *b = new KListViewItem(theKCMLircBase->theActions, (**i).buttonName(), (**i).application(), (**i).function(), (**i).arguments().toString(), (**i).notes());
 		actionMap[b] = *i;
 		if(*i == oldCurrent) { b->setSelected(true); theKCMLircBase->theActions->setCurrentItem(b); }
@@ -401,19 +404,23 @@ void KCMLirc::updateModes()
 
 	IRKick_stub IRKick("irkick", "IRKick");
 	QStringList remotes = IRKick.remotes();
-	for(QStringList::iterator i = remotes.begin(); i != remotes.end(); i++)
+	if(remotes.begin() == remotes.end())
+		theKCMLircBase->theMainLabel->setMaximumSize(32767, 32767);
+	else
+		theKCMLircBase->theMainLabel->setMaximumSize(0, 0);
+	for(QStringList::iterator i = remotes.begin(); i != remotes.end(); ++i)
 	{	Mode mode = allModes.getMode(*i, "");
-		QListViewItem *a = new KListViewItem(theKCMLircBase->theModes, RemoteServer::remoteServer()->getRemoteName(*i), allModes.isDefault(mode) ? "Default" : "", mode.iconFile() == QString::null ? "" : "");
-		if(mode.iconFile() != QString::null)
+		QListViewItem *a = new KListViewItem(theKCMLircBase->theModes, RemoteServer::remoteServer()->getRemoteName(*i), allModes.isDefault(mode) ? "Default" : "", mode.iconFile().isNull() ? "" : "");
+		if(!mode.iconFile().isNull())
 			a->setPixmap(2, KIconLoader().loadIcon(mode.iconFile(), KIcon::Panel));
 		modeMap[a] = mode;	// the null mode
 		if(modeMap[a] == oldCurrent) { a->setSelected(true); theKCMLircBase->theModes->setCurrentItem(a); }
 		a->setOpen(true);
 		ModeList l = allModes.getModes(*i);
-		for(ModeList::iterator j = l.begin(); j != l.end(); j++)
-			if((*j).name() != "")
-			{	QListViewItem *b = new KListViewItem(a, (*j).name(), allModes.isDefault(*j) ? i18n("Default") : "", (*j).iconFile() == QString::null ? "" : "");
-				if((*j).iconFile() != QString::null)
+		for(ModeList::iterator j = l.begin(); j != l.end(); ++j)
+			if(!(*j).name().isEmpty())
+			{	QListViewItem *b = new KListViewItem(a, (*j).name(), allModes.isDefault(*j) ? i18n("Default") : "", (*j).iconFile().isNull() ? "" : "");
+				if(!(*j).iconFile().isNull())
 					b->setPixmap(2, KIconLoader().loadIcon((*j).iconFile(), KIcon::Panel));
 				modeMap[b] = *j;
 				if(*j == oldCurrent) { b->setSelected(true); theKCMLircBase->theModes->setCurrentItem(b); }
@@ -517,26 +524,16 @@ void KCMLirc::save()
 	emit changed(true);
 }
 
-int KCMLirc::buttons()
-{
-    return KCModule::Help;
-}
-
 void KCMLirc::configChanged()
 {
  // insert your saving code here...
     emit changed(true);
 }
 
-QString KCMLirc::quickHelp() const
-{
-    return i18n("Helpful information about the kcmlirc module.");
-}
-
 // TODO: Take this out when I know how
 extern "C"
 {
-	KCModule *create_kcmlirc(QWidget *parent, const char *)
+	KDE_EXPORT KCModule *create_kcmlirc(QWidget *parent, const char *)
 	{	KGlobal::locale()->insertCatalogue("kcmlirc");
 		return new KCMLirc(parent, "KCMLirc");
 	}
