@@ -1,7 +1,7 @@
 /*
   kcmdf.cpp - KcmDiskFree
 
-  written 1998 by Michael Kropfberger <michael.kropfberger@gmx.net>
+  Copyright (C) 1998 by Michael Kropfberger <michael.kropfberger@gmx.net>
   
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -15,7 +15,7 @@
   
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
-  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
    
   */
 
@@ -37,13 +37,10 @@ KDiskFreeWidget::KDiskFreeWidget( QWidget *parent, const char *name )
 {
   setButtons(Help);
 
-  QVBoxLayout *topLayout = new QVBoxLayout( this );
+  QVBoxLayout *topLayout = new QVBoxLayout( this, 0, KDialog::spacingHint() );
 
-  mPage = new QFrame( this, "page" );
-  topLayout->addWidget( mPage, 10 );
-  QVBoxLayout *vbox = new QVBoxLayout( mPage, KDialog::spacingHint() );
-  mKdf = new KDFWidget( mPage, "kdf", false );
-  vbox->addWidget( mKdf, 10 );
+  mKdf = new KDFWidget( this, "kdf", false );
+  topLayout->addWidget( mKdf );
 }
 
 KDiskFreeWidget::~KDiskFreeWidget()
@@ -60,7 +57,7 @@ QString KDiskFreeWidget::quickHelp() const
 
 extern "C"
 {
-  KCModule* create_kdf( QWidget *parent, const char * /*name*/ )
+  KDE_EXPORT KCModule* create_kdf( QWidget *parent, const char * /*name*/ )
   {
     return new KDiskFreeWidget( parent , "kdf" );
   }
