@@ -1,6 +1,6 @@
   /*
 
-    $Id: kedit.cpp,v 1.195.2.1 2004/04/14 11:45:01 binner Exp $
+    $Id: kedit.cpp,v 1.208 2005/02/18 11:40:02 waba Exp $
 
     Copyright (C) 1997 Bernd Johannes Wuebben
                        wuebben@math.cornell.edu
@@ -34,15 +34,12 @@
 #include <kaction.h>
 #include <kapplication.h>
 #include <kcmdlineargs.h>
-#include <kcolorbutton.h>
 #include <kconfigdialog.h>
 #include <kcursor.h>
 #include <keditcl.h>
-#include <kedittoolbar.h>
 #include <kfileitem.h>
 #include <kfontdialog.h>
 #include <kio/netaccess.h>
-#include <kkeydialog.h>
 #include <kmessagebox.h>
 #include <kprinter.h>
 #include <ksavefile.h>
@@ -67,7 +64,6 @@ TopLevel::TopLevel (QWidget *, const char *name)
   : KMainWindow ( 0,name ), kspellconfigOptions(0),
   eframe(0), newWindow(false), kspell(0)
 {
-  setAutoSaveSettings();
   if (!windowList)
   {
      windowList = new QPtrList<TopLevel>;
@@ -83,12 +79,15 @@ TopLevel::TopLevel (QWidget *, const char *name)
   setupStatusBar();
   setupActions();
 
-  resize(550,400); // Default size
-
   readSettings();
 
   setupEditWidget();
 
+  resize( QSize(550, 400).expandedTo(minimumSizeHint()));
+  // Show before setupGUI so that adjust() wont be called.
+  show();
+  setupGUI();
+
   setAcceptDrops(true);
 
   setFileCaption();
@@ -232,16 +231,7 @@ void TopLevel::setupActions()
     // setup Go menu
     KStdAction::gotoLine(this, SLOT(gotoLine()), actionCollection());
 
-    // setup Settings menu
-    createStandardStatusBarAction();
-    setStandardToolBarMenuEnabled(true);
-
     KStdAction::preferences(this, SLOT(showSettings()), actionCollection());
-
-    KStdAction::keyBindings(this, SLOT(editKeys()), actionCollection());
-    KStdAction::configureToolbars(this, SLOT(editToolbars()), actionCollection());
-
-    createGUI();
 }
 
 void TopLevel::setupStatusBar()
@@ -441,30 +431,45 @@ void TopLevel::spell_done(const QString& newtext)
   if (kspell->dlgResult() == 0)
   {
      eframe->setText( newtext);
-     statusBar()->changeItem (i18n("Spellcheck:  Aborted"), ID_GENERAL);
+     statusBar()->changeItem (i18n("Spellcheck:  Aborted."), ID_GENERAL);
   }
   else
   {
-     statusBar()->changeItem (i18n("Spellcheck:  Complete"), ID_GENERAL);
+     statusBar()->changeItem (i18n("Spellcheck:  Complete."), ID_GENERAL);
   }
   kspell->cleanUp();
 }
 
+// Replace ISpell with the name of the actual spell checker.
+// TODO: Use %1 in the original string instead when string freeze is over.
+QString TopLevel::replaceISpell(QString msg, int client)
+{
+  switch(client)
+  {
+    case KS_CLIENT_ISPELL: msg.replace("ISpell", "<b>ispell</b>"); break;
+    case KS_CLIENT_ASPELL: msg.replace("ISpell", "<b>aspell</b>"); break;
+    case KS_CLIENT_HSPELL: msg.replace("ISpell", "<b>hspell</b>"); break;
+  }
+  msg.replace("\n", "<p>");
+  return "<qt>"+msg+"</qt>";
+}
+
 void TopLevel::spell_finished( )
 {
   KSpell::spellStatus status = kspell->status();
+  int client = kspellconfigOptions->client();
   delete kspell;
   kspell = 0;
   if (status == KSpell::Error)
   {
-     KMessageBox::sorry(this, i18n("ISpell could not be started.\n"
-     "Please make sure you have ISpell properly configured and in your PATH."));
+     KMessageBox::sorry(this, replaceISpell(i18n("ISpell could not be started.\n"
+     "Please make sure you have ISpell properly configured and in your PATH."), client));
   }
   else if (status == KSpell::Crashed)
   {
      eframe->spellcheck_stop();
-     statusBar()->changeItem (i18n("Spellcheck:  Crashed"), ID_GENERAL);
-     KMessageBox::sorry(this, i18n("ISpell seems to have crashed."));
+     statusBar()->changeItem (i18n("Spellcheck:  Crashed."), ID_GENERAL);
+     KMessageBox::sorry(this, replaceISpell(i18n("ISpell seems to have crashed."), client));
   }
 }
 
@@ -490,7 +495,7 @@ void TopLevel::file_open( void )
                          i18n("The file you have requested is larger than KEdit is designed for. "
                               "Please ensure you have enough system resources available to safely load this file, "
                               "or consider using a program that is designed to handle large files such as KWrite."),
-                        i18n("Attempting To Open Large File"),
+                        i18n("Attempting to Open Large File"),
                         KStdGuiItem::cont(), "attemptingToOpenLargeFile") == KMessageBox::Cancel)
     {
         return;
@@ -546,7 +551,7 @@ void TopLevel::file_insert()
   {
     KURL url = KTextFileDialog::getOpenURLwithEncoding(
         QString::null, QString::null, this,
-	i18n("Insert File") );
+	i18n("Insert File"), "", KStdGuiItem::insert().text());
     if( url.isEmpty() )
     {
       return;
@@ -839,35 +844,12 @@ void TopLevel::initSpellConfig()
      kspellconfigOptions = new KSpellConfig(0 , "SpellingSettings", 0, false );
 }
 
-void TopLevel::editKeys()
-{
-  KKeyDialog::configure(actionCollection());
-}
-
-
-void TopLevel::editToolbars()
-{
-  saveMainWindowSettings(KGlobal::config(), "MainWindow");
-  KEditToolbar dlg(actionCollection());
-  connect(&dlg, SIGNAL( newToolbarConfig() ), this, SLOT( slotNewToolbarConfig() ));
-  dlg.exec();
-}
-
-
-void TopLevel::slotNewToolbarConfig()
-{
-  createGUI();
-  applyMainWindowSettings(KGlobal::config(), "MainWindow");
-}
-
-
 void TopLevel::search_again()
 {
   eframe->repeatSearch();
   statusbar_slot();
 }
 
-
 void TopLevel::setFileCaption()
 {
   if (m_url.isEmpty())
@@ -968,7 +950,7 @@ void TopLevel::print()
            int y = dy*2;
            while(lineCount < maxLineCount) {
               QString text = eframe->textLine(lineCount);
-              if( text == "" )
+              if( text.isEmpty() )
                 text = " ";	// don't ignore empty lines
               QRect r = p->boundingRect(0, y, body.width(), body.height(),
 			QPainter::ExpandTabs | QPainter::WordBreak, text);
@@ -1160,7 +1142,7 @@ void TopLevel::openURL( const KURL& _url, int _mode )
     {
       if (_mode & OPEN_NEW == 0)
       {
-         KMessageBox::error(this, i18n("Cannot download file!"));
+         KMessageBox::error(this, i18n("Cannot download file."));
          return;
       }
     }
@@ -1269,16 +1251,16 @@ void TopLevel::toggle_overwrite(){
 
 }
 
-static const char description[] = I18N_NOOP("A KDE Text Editor");
+static const char description[] = I18N_NOOP("KDE text editor");
 
 static const KCmdLineOptions options[] =
 {
 	{ "encoding <encoding>", I18N_NOOP("Encoding to use for the following documents"), 0 },
-	{ "+file", I18N_NOOP("File or URL to Open"), 0 },
+	{ "+file", I18N_NOOP("File or URL to open"), 0 },
 	KCmdLineLastOption
 };
 
-extern "C" int kdemain (int argc, char **argv)
+extern "C" KDE_EXPORT int kdemain (int argc, char **argv)
 {
 	bool have_top_window = false;
 
