@@ -196,7 +196,7 @@ class CHexEditorWidget : public QWidget
   private:
     bool selectDocument( const QString &url, bool reloadWhenChanged );
     bool querySave( void );
-    int  readURL( const QString &url, bool insert );
+    int  readURL( const KURL &url, bool insert );
     void writeURL( QString &url );
     bool readFile( const QString &diskPath, const QString &url, bool insert );
     bool writeFile( const QString &diskPath );
