@@ -107,7 +107,16 @@ KJotsMain::KJotsMain(const char* name)
     splitter->setSizePolicy(QSizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding, 2, 1));
 
     // create actions
-    KAction *action = KStdAction::openNew(this, SLOT(newEntry()), actionCollection());
+    KAction *action = new KAction(i18n("Next Book"), QString::null, CTRL + Key_D, this,
+                                  SLOT(nextBook()), actionCollection(), "go_next_book");
+    action = new KAction(i18n("Previous Book"), QString::null, CTRL + SHIFT + Key_D, this,
+                         SLOT(prevBook()), actionCollection(), "go_prev_book");
+    action = new KAction(i18n("Next Page"), QString::null, CTRL + Key_PageDown, this,
+                         SLOT(nextPage()), actionCollection(), "go_next_page");
+    action = new KAction(i18n("Previous Page"), QString::null, CTRL + Key_PageUp, this,
+                         SLOT(prevPage()), actionCollection(), "go_prev_page");
+
+    action = KStdAction::openNew(this, SLOT(newEntry()), actionCollection());
     action->setText(i18n("&New Page"));
     action = new KAction(i18n("New &Book..."), "contents", CTRL + SHIFT + Key_N, this,
             SLOT(createFolder()), actionCollection(), "new_book");
@@ -162,7 +171,7 @@ KJotsMain::KJotsMain(const char* name)
 
     action = KStdAction::preferences(this, SLOT(configure()), actionCollection());
 
-    KActionMenu* bookmarkMenu = new KActionMenu(i18n("Bookmarks"), "bookmarks", actionCollection(), "bookmarks");
+    KActionMenu* bookmarkMenu = new KActionMenu(i18n("&Bookmarks"), "bookmarks", actionCollection(), "bookmarks");
     KJotsBookmarks* bookmarks = new KJotsBookmarks(this);
     connect(bookmarks, SIGNAL(openPage(const QString&)), SLOT(jumpToBookmark(const QString&)));
     new KBookmarkMenu(KBookmarkManager::managerForFile(locateLocal("appdata","bookmarks.xml")),
@@ -310,6 +319,7 @@ bool KJotsMain::createFolder()
 void KJotsMain::slotRenameEntry()
 {
     KJotsEntryBase* entry = dynamic_cast<KJotsEntryBase*>(subjectList->currentItem());
+    
     if (entry)
     {
         entry->rename();
@@ -324,9 +334,9 @@ void KJotsMain::deleteFolder()
         return;
 
     QString msg = i18n("<qt>Are you sure you want to delete the <strong>%1</strong> book?</qt>");
-    int result = KMessageBox::warningYesNo(topLevelWidget(), msg.arg(b->subject()), i18n("Delete Book"));
+    int result = KMessageBox::warningContinueCancel(topLevelWidget(), msg.arg(b->subject()), i18n("Delete Book"),KStdGuiItem::del());
 
-    if (result!=KMessageBox::Yes)
+    if (result!=KMessageBox::Continue)
         return;
 
     KJotsBook* nxt=dynamic_cast<KJotsBook*>(b->nextSibling());
@@ -367,10 +377,10 @@ void KJotsMain::deleteEntry()
     KJotsSubject* cur = currentSubject();
 
     if (!cur ||
-        KMessageBox::warningYesNo(topLevelWidget(),
+        KMessageBox::warningContinueCancel(topLevelWidget(),
                                   i18n("<qt>Are you sure you want to delete the <strong>%1</strong> page?</qt>")
                                   .arg(cur->subject()),
-                                  i18n("Delete Page")) != KMessageBox::Yes)
+                                  i18n("Delete Page"),KStdGuiItem::del()) != KMessageBox::Continue)
     {
         return;
     }
@@ -920,6 +930,183 @@ void KJotsMain::jumpToBookmark(const QString& page)
     }
 }
 
+QListViewItem* KJotsMain::findNextBookItem()
+{
+    QListViewItem* book = currentBook();
+
+    if (!book)
+    {
+        book = subjectList->firstChild();
+    }
+    else
+    {
+        book = book->nextSibling();
+        if (!book)
+        {
+            book = subjectList->firstChild();
+        }
+    }
+
+    return book;
+}
+
+void KJotsMain::nextBook()
+{
+    QListViewItem* book = findNextBookItem();
+    subjectList->setSelected(book, true);
+    jumpToEntry(book);
+}
+
+QListViewItem* KJotsMain::findPrevBookItem()
+{
+    QListViewItem* book = currentBook();
+
+    if (!book)
+    {
+        book = subjectList->firstChild();
+    }
+    else
+    {
+        QListViewItem* item = subjectList->firstChild();
+        while (item && item->nextSibling() && item->nextSibling() != book)
+        {
+            item = item->nextSibling();
+        }
+
+        book = item;
+    }
+
+    return book;
+}
+
+void KJotsMain::prevBook()
+{
+    QListViewItem* book = findPrevBookItem();
+    subjectList->setSelected(book, true);
+    jumpToEntry(book);
+}
+
+void KJotsMain::nextPage()
+{
+    QListViewItem* page = currentSubject();
+
+    if (!page)
+    {
+        QListViewItem* book = findNextBookItem();
+        if (!book || !book->firstChild())
+        {
+            nextBook();
+            return;
+        }
+
+        page = book->firstChild();
+        book->setOpen(true);
+        subjectList->setSelected(page, true);
+        jumpToEntry(page);
+    }
+    else if (page->nextSibling())
+    {
+        subjectList->setSelected(page->nextSibling(), true);
+        jumpToEntry(page->nextSibling());
+    }
+    else
+    {
+        QListViewItem* book = findNextBookItem();
+        if (!book || !book->firstChild())
+        {
+            nextBook();
+            return;
+        }
+
+        book->setOpen(true);
+        if (book->firstChild())
+        {
+            subjectList->setSelected(book->firstChild(), true);
+            jumpToEntry(book->firstChild());
+        }
+        else
+        {
+            subjectList->setSelected(book, true);
+            jumpToEntry(book);
+        }
+    }
+}
+
+void KJotsMain::prevPage()
+{
+    QListViewItem* page = currentSubject();
+
+    if (!page)
+    {
+        QListViewItem* book = findPrevBookItem();
+        book->setOpen(true);
+        page = book->firstChild();
+
+        while (page && page->nextSibling())
+        {
+            page = page->nextSibling();
+        }
+
+        if (page)
+        {
+            subjectList->setSelected(page, true);
+            jumpToEntry(page);
+        }
+        else
+        {
+            subjectList->setSelected(book, true);
+            jumpToEntry(book);
+        }
+        return;
+    }
+
+    QListViewItem* book = page->parent();
+
+    if (!book)
+    {
+        return;
+    }
+
+    QListViewItem* item = book->firstChild();
+
+    if (item == page)
+    {
+        // yay for code duplication! ;-P
+        book = findPrevBookItem();
+        book->setOpen(true);
+        page = book->firstChild();
+
+        while (page && page->nextSibling())
+        {
+            page = page->nextSibling();
+        }
+
+        if (page)
+        {
+            subjectList->setSelected(page, true);
+            jumpToEntry(page);
+        }
+        else
+        {
+            subjectList->setSelected(book, true);
+        }
+        return;
+    }
+    while (item && item->nextSibling() != page)
+    {
+        item = item->nextSibling();
+    }
+
+    if (!item)
+    {
+        prevBook();
+        return;
+    }
+
+    subjectList->setSelected(item, true);
+    jumpToEntry(item);
+}
+
 void KJotsMain::jumpToEntry(QListViewItem* entry)
 {
     if (currentEntry == entry)
@@ -930,7 +1117,6 @@ void KJotsMain::jumpToEntry(QListViewItem* entry)
 
     if (entry == 0)
     {
-        setCaption(kapp->makeStdCaption(QString::null));
         me_text->clear();
         currentEntry = 0;
     }
@@ -938,7 +1124,6 @@ void KJotsMain::jumpToEntry(QListViewItem* entry)
     {
         KJotsBook* book = static_cast<KJotsBook*>(entry);
 
-        setCaption(kapp->makeStdCaption(book->subject()));
         QString TOC;
         QString pageText;
         QListViewItem* child = entry->firstChild();
@@ -967,6 +1152,7 @@ void KJotsMain::jumpToEntry(QListViewItem* entry)
         {
             pageText = "<h3>" + i18n("Table of Contents") + "</h3><ul>" + TOC + "</ul><hr>" + pageText;
         }
+
         roTextView->setText(QString("<h1>%1</h1>").arg(book->subject()) + pageText);
         roTextView->setCursorPosition(0, 0);
         textStack->raiseWidget(roTextView);
@@ -977,17 +1163,40 @@ void KJotsMain::jumpToEntry(QListViewItem* entry)
         textStack->raiseWidget(me_text);
         syncTextWithEntry(dynamic_cast<KJotsSubject*>(entry));
 
-        // TODO: this will have to be fixed if/when we allow arbitrary depth pages
-        QString caption = dynamic_cast<KJotsEntryBase*>(entry->parent())->subject() +
-                          " / " +
-                          dynamic_cast<KJotsEntryBase*>(entry)->subject();
-        setCaption(kapp->makeStdCaption(caption));
         currentEntry = static_cast<KJotsEntryBase*>(entry);
     }
 
+    updateCaption();
     updateMenu();
 }
 
+void KJotsMain::updateCaption()
+{
+    // TODO: this will have to be fixed if/when we allow arbitrary depth pages
+    
+    QListViewItem* e = subjectList->currentItem();
+   
+    if (!e)
+    {
+        setCaption(kapp->makeStdCaption(QString::null));
+
+        return;
+    }
+
+    if (dynamic_cast<KJotsBook*>(e))
+    {
+        setCaption(kapp->makeStdCaption(static_cast<KJotsBook*>(e)->subject()));
+    }
+    else if (dynamic_cast<KJotsSubject*>(e))
+    {
+        QString caption = static_cast<KJotsEntryBase*>(e->parent())->subject() +
+                          " / " +
+                          static_cast<KJotsEntryBase*>(e)->subject();
+
+        setCaption(kapp->makeStdCaption(caption));
+    }
+}
+
 void KJotsMain::slotItemRenamed(QListViewItem* item, const QString& str, int  /*col*/)
 {
     KJotsEntryBase* entry = dynamic_cast<KJotsEntryBase*>(item);
@@ -995,6 +1204,7 @@ void KJotsMain::slotItemRenamed(QListViewItem* item, const QString& str, int  /*
     if (entry)
     {
         entry->setSubject(str);
+        updateCaption();
     }
 }
 
