@@ -9,7 +9,7 @@
  *
  * This file contains the implementation of the main laptop battery monitoring daemon
  *
- * $Id: laptop_daemon.cpp,v 1.54 2004/06/26 14:15:02 binner Exp $
+ * $Id: laptop_daemon.cpp,v 1.55 2004/12/08 01:41:45 mueller Exp $
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -52,7 +52,7 @@
 
 extern "C"
 {
-       KDEDModule *create_klaptopdaemon(const QCString& name) {
+       KDE_EXPORT KDEDModule *create_klaptopdaemon(const QCString& name) {
 		return new laptop_daemon(name);
         }
 }
