@@ -1,5 +1,5 @@
 /*
- * pcmcia.h
+ * power.h
  *
  * Copyright (c) 1999 Paul Campbell <paul@taniwha.com>
  *
@@ -18,7 +18,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  */
 
 
@@ -29,10 +29,14 @@
 #include <qstring.h>
 
 class QWidget;
+class QSlider;
 class QButtonGroup;
 class QRadioButton;
 class QSpinBox;
 class KConfig;
+class QCheckBox;
+class KComboBox;
+class KDoubleSpinBox;
 
 class PowerConfig : public KCModule
 {
@@ -46,10 +50,6 @@ public:
 
   virtual QString quickHelp() const;
 
-private slots:
-
-  void configChanged();
-
 
 private:
 
@@ -59,11 +59,35 @@ private:
 
   QButtonGroup *nopowerBox;
   QRadioButton *nopowerStandby, *nopowerSuspend, *nopowerOff, *nopowerHibernate;
+  QCheckBox *nopowerBrightness;
+  QSlider *nopowerValBrightness;
+  QCheckBox *nopowerThrottle;
+  KComboBox *nopowerValThrottle;
+  QCheckBox *nopowerPerformance;
+  KComboBox *nopowerValPerformance;
   QButtonGroup *powerBox;
   QRadioButton *powerStandby, *powerSuspend, *powerOff, *powerHibernate;
+  QCheckBox *powerBrightness;
+  QSlider *powerValBrightness;
+  QCheckBox *powerThrottle;
+  KComboBox *powerValThrottle;
+  QCheckBox *powerPerformance;
+  KComboBox *powerValPerformance;
   QSpinBox *noeditwait;
   QSpinBox *editwait;
+  QCheckBox *enablelav;
+  QCheckBox *noenablelav;
+  KDoubleSpinBox *noeditlav;
+  KDoubleSpinBox *editlav;
   int edit_wait, noedit_wait;
+  int power_bright_val, nopower_bright_val;
+  bool nopower_bright_enabled, power_bright_enabled;
+  bool nopower_throttle_enabled, power_throttle_enabled;
+  QString nopower_throttle_val, power_throttle_val;
+  bool nopower_performance_enabled, power_performance_enabled;
+  bool lav_enabled, nolav_enabled;
+  float edit_lav, noedit_lav;
+  QString nopower_performance_val, power_performance_val;
 
   KConfig *config;
   int power, nopower, apm;
