@@ -11,7 +11,7 @@
          This code may be linked against any version of the Qt toolkit
          from Troll Tech, Norway. $
 
-   $Id: kvaio.h,v 1.7.4.1 2004/08/23 21:13:10 kloecker Exp $
+   $Id: kvaio.h,v 1.9 2005/01/07 08:26:02 ossi Exp $
 
    * Portions of this code are
    * (C) 2001-2002 Stelian Pop <stelian@popies.net> and
@@ -34,7 +34,7 @@
 
 extern "C" {
 #include <X11/Xlib.h>
-#include <X11/extensions/XTest.h>
+//#include <X11/extensions/XTest.h>
 }
 
 class KVaio;
