@@ -26,12 +26,7 @@
 #endif
 
 #include "kmultiformlistboxfactory.h"
-#include "kmultiformlistbox-shower.h"
-#include "kmultiformlistboxentry.h"
 #include "kmultiformlistbox.h"
-#include <qptrlist.h>
-#include <qlayout.h>
-#include <qscrollview.h>
 class WindowListboxItem;
 
 
