@@ -2,7 +2,7 @@
  *
  *  Copyright (C) 2001  Robbie Ward <linuxphreak@gmx.co.uk>
  *
- *  $Id: ksimfsystem.cpp,v 1.62 2003/08/17 13:12:09 hausmann Exp $
+ *  $Id: ksimfsystem.cpp,v 1.63 2004/04/04 16:52:09 waba Exp $
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -86,7 +86,11 @@ Fsystem::Fsystem(KSim::PluginObject *parent, const char *name)
    KSim::PluginView(parent, name)
 {
   config()->setGroup("Fsystem");
-  (new QVBoxLayout(this))->setAutoAdd(true);
+  QVBoxLayout *vbLayout = new QVBoxLayout(this);
+  vbLayout->setAutoAdd(true);
+
+  QSpacerItem *item = new QSpacerItem(0, 0, QSizePolicy::Expanding, QSizePolicy::Expanding);
+  vbLayout->addItem(item);
 
   m_mountEntries = makeList(config()->readListEntry("mountEntries"));
   m_showPercentage = config()->readBoolEntry("ShowPercentage", true);
